@@ -58,7 +58,8 @@ enum dm_dev_type {
     DM_CMIS_CABLE,
     DM_SFP_CABLE,
     DM_LINKX, /* linkx chip */
-    DM_GEARBOX
+    DM_GEARBOX,
+    DM_RETIMER
 };
 
 struct device_info {
@@ -225,7 +226,7 @@ static struct device_info g_devs_info[] = {
         DeviceConnectX8,                                      /* dm_id */
         0x21e,                                                /* hw_dev_id */
         -1,                                                   /* hw_rev_id */
-        -1,                                                   /* sw_dev_id */
+        4131,                                                 /* sw_dev_id */
         "ConnectX8",                                          /* name */
         4,                                                    /* port_num */
         DM_HCA                                                /* dev_type */
@@ -419,6 +420,15 @@ static struct device_info g_devs_info[] = {
         -1,                                                /* port_num */
         DM_LINKX                                           /* dev_type */
     },
+    {
+        DeviceArcusE, // dm_id
+        0xb200,       // hw_dev_id (other versions 0x6f,0x73)
+        -1,           // hw_rev_id
+        -1,           // sw_dev_id
+        "ArcusE",     // name
+        -1,           // port_num
+        DM_RETIMER    // dev_type
+    },
     {
         DeviceSecureHost,                                      /* dm_id */
         0xcafe,                                                /* hw_dev_id */
@@ -465,11 +475,11 @@ static struct device_info g_devs_info[] = {
         DM_SWITCH                                            /* dev_type */
     },
     {
-        DeviceGB100,                                      /* dm_id */
+        DeviceBW00,                                      /* dm_id */
         0x2900,                                           /* hw_dev_id */
         -1,                                               /* hw_rev_id */
         10496,                                            /* sw_dev_id */
-        "GB100",                                          /* name */
+        "BW00",                                          /* name */
         128,                                              /* port_num NEED_CHECK */
         DM_SWITCH                                         /* dev_type */
     },
@@ -801,6 +811,22 @@ dm_dev_id_t dm_dev_sw_id2type(int sw_dev_id)
     return DeviceUnknown;
 }
 
+
+const char* dm_dev_hw_id2str(unsigned int hw_dev_id)
+{
+    const struct device_info* p = g_devs_info;
+
+    while (p->dm_id != DeviceUnknown) {
+        if (hw_dev_id == p->hw_dev_id) {
+            return p->name;
+        }
+        p++;
+    }
+
+    return NULL;
+}
+
+
 int dm_get_hw_ports_num(dm_dev_id_t type)
 {
     return get_entry(type)->port_num;
@@ -870,6 +896,11 @@ int dm_dev_is_cable(dm_dev_id_t type)
             dm_dev_is_cmis_cable(type));
 }
 
+int dm_dev_is_retimer(dm_dev_id_t type)
+{
+    return get_entry(type)->dev_type == DM_RETIMER && type == DeviceArcusE;
+}
+
 u_int32_t dm_get_hw_dev_id(dm_dev_id_t type)
 {
     return get_entry(type)->hw_dev_id;
@@ -902,7 +933,7 @@ int dm_is_livefish_mode(mfile* mf)
         return 1;
     }
     dm_dev_id_t devid_t = DeviceUnknown;
-    u_int32_t   devid = 0;
+    u_int32_t   devid = 0; // hw dev ID
     u_int32_t   revid = 0;
     int         rc = dm_get_device_id(mf, &devid_t, &devid, &revid);
 
@@ -916,7 +947,8 @@ int dm_is_livefish_mode(mfile* mf)
     if (dm_is_4th_gen(devid_t)) {
         return (devid == swid - 1);
     } else {
-        return (devid == swid);
+        int zombiefish = is_zombiefish_device(mf);
+        return ((devid == swid) || zombiefish);
     }
 
     return 0;
@@ -942,6 +974,21 @@ int dm_is_gb100(dm_dev_id_t type)
     return (type == DeviceGB100);
 }
 
+int dm_is_gr100(dm_dev_id_t type)
+{
+    return (type == DeviceGR100);
+}
+
+int dm_is_gpu(dm_dev_id_t type)
+{
+    return (dm_is_gb100(type) || dm_is_gb100(type));
+}
+
+int dm_is_bw00(dm_dev_id_t type)
+{
+    return (type == DeviceBW00);
+}
+
 int dm_is_cx7(dm_dev_id_t type)
 {
     return (type == DeviceConnectX7);
@@ -955,14 +1002,14 @@ int dm_is_new_gen_switch(dm_dev_id_t type)
 int dm_dev_is_raven_family_switch(dm_dev_id_t type)
 {
     return (dm_dev_is_switch(type) &&
-            (type == DeviceQuantum || type == DeviceQuantum2 || type == DeviceQuantum3 || type == DeviceGB100 ||
+            (type == DeviceQuantum || type == DeviceQuantum2 || type == DeviceQuantum3 || type == DeviceBW00 ||
              type == DeviceSpectrum2 || type == DeviceSpectrum3 || type == DeviceSpectrum4));
 }
 
 int dm_dev_is_ib_switch(dm_dev_id_t type)
 {
     return (dm_dev_is_switch(type) && (type == DeviceQuantum || type == DeviceQuantum2 || type == DeviceQuantum3 ||
-                                       type == DeviceGB100 || type == DeviceSwitchIB || type == DeviceSwitchIB2));
+                                       type == DeviceBW00 || type == DeviceSwitchIB || type == DeviceSwitchIB2));
 }
 
 int dm_dev_is_eth_switch(dm_dev_id_t type)
@@ -985,6 +1032,12 @@ int dm_dev_is_fs4(dm_dev_id_t type)
            type == DeviceSpectrum4 || type == DeviceSpectrum2 || type == DeviceSpectrum3 || type == DeviceGearBox ||
            type == DeviceGearBoxManager;
 }
+
+int dm_dev_is_fs5(dm_dev_id_t type)
+{
+    return type == DeviceConnectX8 || type == DeviceQuantum3 || type == DeviceBlueField4;
+}
+
 int dm_is_ib_access(mfile* mf)
 {
     return (mf->flags & MDEVS_IB);
