@@ -100,6 +100,8 @@ extern "C"
         DeviceCableCMIS,
         DeviceCableCMISPaging,
         DeviceBW00,    // Blackwell
+        DeviceGB100,
+        DeviceGR100,
         DeviceArcusPTC, // ArcusP Test Chip
         DeviceArcusP,
         DeviceArcusE,
@@ -177,6 +179,11 @@ extern "C"
      * Returns the device name as a "const char*"
      */
     const char* dm_dev_type2str(dm_dev_id_t type);
+    
+    /**
+     * Returns the device name as a "const char*"
+     */
+    const char* dm_dev_hw_id2str(unsigned int hw_dev_id);
 
     /**
      * Returns the device id
@@ -231,7 +238,7 @@ extern "C"
     /**
      * A predicate returning if the device is an ArcusE chipset
      */
-    int dm_dev_is_retimer_arcuse(dm_dev_id_t type);
+    int dm_dev_is_retimer(dm_dev_id_t type);
 
     /**
      * Returns the max num of ports or -1 on error
@@ -254,8 +261,25 @@ extern "C"
      */
     int dm_is_fpp_supported(dm_dev_id_t type);
 
+    /**
+     * A predicate returning if the device is a gb100
+     */
+    int dm_is_gb100(dm_dev_id_t type);
+
+    /**
+     * A predicate returning if the device is a gpu device
+     */
+    int dm_is_gpu(dm_dev_id_t type);
+
+    /**
+     * A predicate returning if the device is a gr100
+     */
+    int dm_is_gr100(dm_dev_id_t type);
+
     int dm_is_4th_gen(dm_dev_id_t type);
 
+    int dm_dev_is_fs5(dm_dev_id_t type);
+
     int dm_is_5th_gen_hca(dm_dev_id_t type);
 
     int dm_is_connectib(dm_dev_id_t type);
