@@ -403,9 +403,10 @@ typedef enum fs3_section
     FS4_CERTIFICATE_CHAINS_2 = 0xf5,
     FS4_ROOT_CERTIFICATES_1 = 0xf6,
     FS4_ROOT_CERTIFICATES_2 = 0xf7,
+    FS4_TOOLS_AREA = 0xf9,
     FS4_HASHES_TABLE = 0xfa,
     FS4_HW_PTR = 0xfb,
-    FS4_TOOLS_AREA = 0xfc,
+    FS4_FW_DEBUG_DUMP = 0xfc,
     FS3_ITOC = 0xfd,
     FS3_DTOC = 0xfe,
     FS3_END = 0xff,
