@@ -3,6 +3,7 @@
  * flint_io.h - FLash INTerface
  *
  * Copyright (c) 2011 Mellanox Technologies Ltd.  All rights reserved.
+ * Copyright (c) 2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -61,21 +62,27 @@
 
 #define IO_MAX_BANKS_NUM 4
 
-typedef struct ext_flash_attr {
+typedef struct ext_flash_attr
+{
     u_int8_t banks_num;
     u_int32_t hw_dev_id;
     u_int32_t rev_id;
-    char *type_str;   // NULL if not available
+    char* type_str; // NULL if not available
+    u_int32_t jedec_id;
     u_int32_t size;
     u_int32_t sector_size; // minimal sec
     int block_write;
     int command_set;
     u_int8_t quad_en_support;
+    u_int8_t driver_strength_support;
     u_int8_t dummy_cycles_support;
 
     u_int8_t quad_en;
     MfError mf_get_quad_en_rc;
 
+    u_int8_t driver_strength;
+    MfError mf_get_driver_strength_rc;
+
     u_int8_t dummy_cycles;
     MfError mf_get_dummy_cycles_rc;
 
@@ -86,59 +93,50 @@ typedef struct ext_flash_attr {
 
 } ext_flash_attr_t;
 
-
-
 // Common base class for Flash and for FImage
-class MLXFWOP_API FBase : public FlintErrMsg {
+class MLXFWOP_API FBase : public FlintErrMsg
+{
 public:
-
-    enum {
+    enum
+    {
         Fwm_Default = 0,
         Fwm_4KB = 1,
         Fwm_64KB = 2
     };
 
-
-    FBase(bool is_flash) :
-        _is_image_in_odd_chunks(false),
-        _log2_chunk_size(0),
-        _is_flash(is_flash),
-        _advErrors(true) {}
+    FBase(bool is_flash) : _is_image_in_odd_chunks(false), _log2_chunk_size(0), _is_flash(is_flash), _advErrors(true) {}
     virtual ~FBase() {}
 
-    virtual bool open(uefi_Dev_t *uefi_dev,
-        uefi_dev_extra_t *uefi_extra,
-        bool force_lock = false,
-        bool advErr = true) = 0;
+    virtual bool
+      open(uefi_Dev_t* uefi_dev, uefi_dev_extra_t* uefi_extra, bool force_lock = false, bool advErr = true) = 0;
 
     virtual bool open(const char*, bool, bool) = 0;
 
-    virtual bool open(const char *device, bool, bool, int, flash_params_t*, int, bool, int) = 0;
+    virtual bool open(const char* device, bool, bool, int, flash_params_t*, int, bool, int) = 0;
 
     virtual bool is_fifth_gen() = 0;
     virtual void close() = 0;
-    virtual bool read(u_int32_t addr, u_int32_t *data) = 0;
-    virtual bool read(u_int32_t addr, void *data, int len,
-                      bool verbose = false,
-                      const char *message = "") = 0;
-    virtual bool read_modify_write(u_int32_t phy_addr, void *data, int cnt, bool noerase = false) = 0;
+    virtual bool read(u_int32_t addr, u_int32_t* data) = 0;
+    virtual bool read(u_int32_t addr, void* data, int len, bool verbose = false, const char* message = "") = 0;
+    virtual bool read_modify_write(u_int32_t phy_addr, void* data, int cnt, bool noerase = false) = 0;
 
-    virtual bool read_modify_write_phy(u_int32_t phy_addr, void *data, int cnt, bool noerase = false) = 0;
+    virtual bool read_modify_write_phy(u_int32_t phy_addr, void* data, int cnt, bool noerase = false) = 0;
 
-    virtual bool write(u_int32_t addr, void *data, int cnt, bool noerase = false) = 0;
+    virtual bool write(u_int32_t addr, void* data, int cnt) { return write(addr, data, cnt, false); }
+    virtual bool write(u_int32_t addr, void* data, int cnt, bool noerase) = 0;
 
-    virtual bool write_phy(u_int32_t phy_addr, void *data, int cnt, bool noerase = false) = 0;
+    virtual bool write_phy(u_int32_t phy_addr, void* data, int cnt, bool noerase = false) = 0;
 
     virtual bool write(u_int32_t addr, u_int32_t data) = 0;
     virtual bool set_flash_working_mode(int mode = FBase::Fwm_Default) = 0;
     virtual bool set_flash_utilization(bool, int) = 0;
     virtual int get_flash_working_mode() = 0;
 
-    virtual bool sw_reset() = 0;
     virtual bool set_no_flash_verify(bool) = 0;
 
     virtual u_int32_t get_sector_size() = 0;
     virtual u_int32_t get_size() = 0;
+    virtual u_int32_t get_effective_size() = 0;
 
     virtual u_int32_t get_dev_id() = 0;
     virtual u_int32_t get_rev_id() = 0;
@@ -146,12 +144,12 @@ public:
     virtual mfile* getMfileObj() = 0;
     virtual mflash* getMflashObj() = 0;
     virtual bool erase_sector(u_int32_t addr) = 0;
-    virtual BinIdT    get_bin_id() { return UNKNOWN_BIN; };
-    Crc16&            get_image_crc() { return _image_crc; };
-    bool              is_flash() { return _is_flash; };
+    virtual BinIdT get_bin_id() { return UNKNOWN_BIN; };
+    Crc16& get_image_crc() { return _image_crc; };
+    bool is_flash() { return _is_flash; };
 
-    bool read_phy(u_int32_t phy_addr, void *data, int len);
-    bool read_phy(u_int32_t phy_addr, u_int32_t *data);
+    bool read_phy(u_int32_t phy_addr, void* data, int len);
+    bool read_phy(u_int32_t phy_addr, u_int32_t* data);
 
     virtual void set_address_convertor(u_int32_t log2_chunk_size, bool is_image_in_odd_chunks)
     {
@@ -170,15 +168,15 @@ public:
         return phys_addr;
     }
 
-    u_int32_t   get_log2_chunk_size() { return _log2_chunk_size; }
-    bool        get_is_image_in_odd_chunks() { return _is_image_in_odd_chunks; }
+    u_int32_t get_log2_chunk_size() { return _log2_chunk_size; }
+    bool get_is_image_in_odd_chunks() { return _is_image_in_odd_chunks; }
 
-    enum {
+    enum
+    {
         MAX_FLASH = 4 * 1048576
     };
 
 protected:
-
     // Address translation functions for ConnectX.
     // Translate between contiguous "logical" addresses
 
@@ -192,12 +190,14 @@ protected:
     u_int32_t cont2phys(u_int32_t cont_addr)
     {
         u_int32_t result;
-        if (_log2_chunk_size) {
-            result = (cont_addr       & (0xffffffff >> (32 - _log2_chunk_size))) |
+        if (_log2_chunk_size)
+        {
+            result = (cont_addr & (0xffffffff >> (32 - _log2_chunk_size))) |
                      (_is_image_in_odd_chunks << _log2_chunk_size) |
                      ((cont_addr << 1) & (0xffffffff << (_log2_chunk_size + 1)));
         }
-        else {
+        else
+        {
             result = cont_addr;
         }
         return result;
@@ -206,11 +206,13 @@ protected:
     u_int32_t phys2cont(u_int32_t phys_addr)
     {
         u_int32_t result;
-        if (_log2_chunk_size) {
-            result =  (phys_addr       & (0xffffffff >> (32 - _log2_chunk_size))) |
-                     ((phys_addr >> 1) & (0xffffffff << (     _log2_chunk_size)));
+        if (_log2_chunk_size)
+        {
+            result = (phys_addr & (0xffffffff >> (32 - _log2_chunk_size))) |
+                     ((phys_addr >> 1) & (0xffffffff << (_log2_chunk_size)));
         }
-        else {
+        else
+        {
             result = phys_addr;
         }
         return result;
@@ -218,10 +220,12 @@ protected:
 
     bool readWriteCommCheck(u_int32_t addr, int len)
     {
-        if (addr & 0x3) {
+        if (addr & 0x3)
+        {
             return errmsg("Address should be 4-bytes aligned.");
         }
-        if (len & 0x3) {
+        if (len & 0x3)
+        {
             return errmsg("Length should be 4-bytes aligned.");
         }
         return true;
@@ -242,33 +246,25 @@ protected:
     const bool _is_flash;
     // show advanced error msgs
     bool _advErrors;
-
 };
 
-
-
-
 // Flash image (R/W)
-class MLXFWOP_API FImage : public FBase {
+class MLXFWOP_API FImage : public FBase
+{
 public:
-    FImage() :
-        FBase(false),
-        _fname(0),
-        _buf(),
-        _isFile(false),
-        _len(0) {}
+    FImage() : FBase(false), _fname(0), _buf(), _isFile(false), _len(0) {}
     virtual ~FImage() { close(); }
 
     u_int32_t* getBuf();
-    u_int32_t    getBufLength() { return _len; }
-    virtual bool open(const char *fname, bool read_only = false, bool advErr = true);
+    u_int32_t getBufLength() { return _len; }
+    virtual bool open(const char* fname, bool read_only = false, bool advErr = true);
     using FBase::open;
-    bool open(u_int32_t *buf, u_int32_t len, bool advErr = true);
+    bool open(u_int32_t* buf, u_int32_t len, bool advErr = true);
     virtual void close();
-    virtual bool read(u_int32_t addr, u_int32_t *data);
-    virtual bool read(u_int32_t addr, void *data, int len, bool verbose = false, const char *message = "");
-    virtual bool write(u_int32_t addr, void *data, int cnt);
-    virtual bool write(u_int32_t, void *, int, bool)
+    virtual bool read(u_int32_t addr, u_int32_t* data);
+    virtual bool read(u_int32_t addr, void* data, int len, bool verbose = false, const char* message = "");
+    virtual bool write(u_int32_t addr, void* data, int cnt);
+    virtual bool write(u_int32_t, void*, int, bool)
     {
         check_uefi_build();
         return false;
@@ -283,21 +279,22 @@ public:
         check_uefi_build();
         return false;
     }
-    virtual bool open(uefi_Dev_t *, uefi_dev_extra_t *, bool, bool)
+    virtual bool open(uefi_Dev_t*, uefi_dev_extra_t*, bool, bool)
     {
         check_uefi_build();
         return false;
     }
-    virtual bool open(const char*, bool, bool, int, flash_params_t*, int, bool, int) {
-        check_uefi_build();
-        return false;
-    }
-    virtual bool read_modify_write_phy(u_int32_t, void *, int, bool)
+    virtual bool open(const char*, bool, bool, int, flash_params_t*, int, bool, int)
     {
         check_uefi_build();
         return false;
     }
-    virtual bool read_modify_write(u_int32_t, void *, int, bool = false)
+    virtual bool read_modify_write_phy(u_int32_t, void*, int, bool)
+    {
+        check_uefi_build();
+        return false;
+    }
+    virtual bool read_modify_write(u_int32_t, void*, int, bool = false)
     {
         check_uefi_build();
         return false;
@@ -317,11 +314,6 @@ public:
         check_uefi_build();
         return false;
     }
-    virtual bool sw_reset()
-    {
-        check_uefi_build();
-        return false;
-    }
     virtual bool set_no_flash_verify(bool)
     {
         check_uefi_build();
@@ -334,6 +326,7 @@ public:
     }
     virtual u_int32_t get_sector_size();
     virtual u_int32_t get_size() { return getBufLength(); }
+    virtual u_int32_t get_effective_size() { return get_size(); }
     virtual u_int32_t get_dev_id() { return 0; }
     virtual u_int32_t get_rev_id() { return 0; }
     virtual mfile* getMfileObj()
@@ -347,23 +340,23 @@ public:
         return (mflash*)NULL;
     }
     virtual bool is_fifth_gen() { return false; }
+
 private:
     bool readFileGetBuffer(std::vector<u_int8_t>& dataBuf);
     bool writeEntireFile(std::vector<u_int8_t>& fileContent);
     bool getFileSize(int& fileSize);
-    const char *_fname;
+    const char* _fname;
     std::vector<u_int8_t> _buf;
     bool _isFile;
     u_int32_t _len;
 };
 
-
 //
 // Flash access (R/W)
 //
 
-
-class MLXFWOP_API Flash : public FBase {
+class MLXFWOP_API Flash : public FBase
+{
 public:
     Flash() :
         FBase(true),
@@ -385,21 +378,17 @@ public:
 
     // FBase Interface
 
-    virtual bool open(const char *device,
+    virtual bool open(const char* device,
                       bool force_lock = false,
                       bool read_only = false,
                       int num_of_banks = 4,
-                      flash_params_t *flash_params = (flash_params_t*)NULL,
+                      flash_params_t* flash_params = (flash_params_t*)NULL,
                       int ignoe_cache_replacement = 0,
                       bool advErr = true,
                       int cx3_fw_access = 0);
     using FBase::open;
 
-    virtual bool open(uefi_Dev_t *uefi_dev,
-                      uefi_dev_extra_t *uefi_extra,
-                      bool force_lock = false,
-                      bool advErr = true);
-
+    virtual bool open(uefi_Dev_t* uefi_dev, uefi_dev_extra_t* uefi_extra, bool force_lock = false, bool advErr = true);
 
     virtual bool open(const char*, bool, bool)
     {
@@ -412,23 +401,16 @@ public:
 
     virtual void close();
 
-    virtual bool read(u_int32_t addr,
-                      u_int32_t *data);
+    virtual bool read(u_int32_t addr, u_int32_t* data);
 
-    virtual bool read(u_int32_t addr,
-                      void *data,
-                      int len,
-                      bool verbose = false,
-                      const char *message = "");
-    virtual bool write_phy(u_int32_t phy_addr, void *data, int cnt, bool noerase = false); // read modify write
-    virtual bool read_modify_write_phy(u_int32_t phy_addr, void *data, int cnt, bool noerase = false); // read modify write
+    virtual bool read(u_int32_t addr, void* data, int len, bool verbose = false, const char* message = "");
+    virtual bool write_phy(u_int32_t phy_addr, void* data, int cnt, bool noerase = false); // read modify write
+    virtual bool read_modify_write_phy(u_int32_t phy_addr, void* data, int cnt, bool noerase = false); // read modify
+                                                                                                       // write
     bool write_phy(u_int32_t phy_addr, u_int32_t data); // read modify write
     bool erase_sector_phy(u_int32_t phy_addr);
 
-    bool         update_boot_addr(u_int32_t boot_addr)
-    {
-        return mf_update_boot_addr(_mfl, boot_addr) == MFE_OK;
-    }
+    bool update_boot_addr(u_int32_t boot_addr) { return mf_update_boot_addr(_mfl, boot_addr) == MFE_OK; }
     //
     // Flash Interface
     //
@@ -436,68 +418,60 @@ public:
     u_int32_t get_current_sector_size() { return _curr_sector_size; }
     u_int32_t get_sector_size() { return _attr.sector_size; }
     virtual u_int32_t get_size() { return _attr.size; }
+    virtual u_int32_t get_effective_size();
 
     virtual u_int32_t get_dev_id() { return _attr.hw_dev_id; }
     u_int32_t get_rev_id() { return _attr.rev_id; }
-    BinIdT    get_bin_id() { return _attr.bin_id; };
+    BinIdT get_bin_id() { return _attr.bin_id; };
     u_int32_t get_port_num() { return _port_num; }
-    u_int8_t  get_cr_space_locked() { return _cr_space_locked; }
-    bool  get_ignore_cache_replacment() { return _ignore_cache_replacement; }
-
-    virtual bool sw_reset();
+    u_int8_t get_cr_space_locked() { return _cr_space_locked; }
+    bool get_ignore_cache_replacment() { return _ignore_cache_replacement; }
 
     virtual bool set_no_flash_verify(bool val);
-    static void get_flash_list(char *flash_list, int buffer_size) { return mf_flash_list(flash_list, buffer_size); }
+    static void get_flash_list(char* flash_list, int buffer_size) { return mf_flash_list(flash_list, buffer_size); }
 
     // Write and Erase functions are performed by the Command Set
 
     virtual bool erase_sector(u_int32_t addr);
 
-    virtual bool write(u_int32_t addr,
-                       void *data,
-                       int cnt,
-                       bool noerase = false);
+    virtual bool write(u_int32_t addr, void* data, int cnt, bool noerase = false);
 
-    virtual bool read_modify_write(u_int32_t phy_addr, void *data, int cnt, bool noerase = false);
+    virtual bool read_modify_write(u_int32_t phy_addr, void* data, int cnt, bool noerase = false);
 
-    virtual bool write(u_int32_t addr,
-                       u_int32_t data);
+    virtual bool write(u_int32_t addr, u_int32_t data);
 
     virtual bool enable_hw_access(u_int64_t key);
 
     virtual bool disable_hw_access();
 
-    bool         disable_hw_access(u_int64_t key);
-    virtual bool         is_fifth_gen();
+    bool disable_hw_access(u_int64_t key);
+    virtual bool is_fifth_gen();
     const char* getFlashType();
 
-    bool         get_attr(ext_flash_attr_t& attr);
+    bool get_attr(ext_flash_attr_t& attr);
 
-    bool         set_attr(char *param_name,
-                          char *param_val_str);
+    bool set_attr(char* param_name, char* param_val_str);
 
     bool flash_working_mode_supported() { return _attr.support_sub_and_sector; }
     virtual int get_flash_working_mode() { return _flash_working_mode; }
     virtual bool set_flash_working_mode(int mode = FBase::Fwm_Default);
     virtual bool set_flash_utilization(bool, int);
     bool is_flash_write_protected();
-    static void  deal_with_signal();
+    static void deal_with_signal();
 
     mfile* getMfileObj() { return mf_get_mfile(_mfl); }
     mflash* getMflashObj() { return _mfl; }
 
-    enum {
+    enum
+    {
         TRANS = 4096
     };
 
+    bool open_com_checks(const char* device, int rc, bool force_lock);
 
-
-    bool open_com_checks(const char *device,
-                         int rc,
-                         bool force_lock);
-
-//needed for printing flash status in flint hw query cmd
+// needed for printing flash status in flint hw query cmd
 #define QUAD_EN_PARAM "QuadEn"
+#define DRIVER_STRENGTH_PARAM "DriverStrength"
 #define DUMMY_CYCLES_PARAM "DummyCycles"
 #define FLASH_NAME "Flash"
 #define WRITE_PROTECT "WriteProtected"
@@ -508,17 +482,16 @@ public:
 #define WP_DISABLED_STR "Disabled"
 
 protected:
-    bool write_sector_with_erase(u_int32_t addr, void *data, int cnt);
-    bool write_with_erase(u_int32_t addr, void *data, int cnt);
+    bool write_sector_with_erase(u_int32_t addr, void* data, int cnt);
+    bool write_with_erase(u_int32_t addr, void* data, int cnt);
 
-
-    mflash *_mfl;
+    mflash* _mfl;
     flash_attr _attr;
     bool _no_flash_verify;
     bool _ignore_cache_replacement; // for FS3 devices flash access.
 
     u_int32_t _curr_sector;
-    u_int32_t _curr_sector_size;  // can work with both 4KB and 64KB sectors
+    u_int32_t _curr_sector_size; // can work with both 4KB and 64KB sectors
     u_int32_t _port_num;
     u_int8_t _cr_space_locked;
     int _flash_working_mode;
