@@ -74,6 +74,10 @@ u_int8_t FsCtrlOperations::FwType()
     {
         return FIT_FS4;
     }
+    else if (fwFormat == FS_FS5_GEN)
+    {
+        return FIT_FS5;
+    }
     return FIT_FSCTRL;
 }
 
@@ -232,6 +236,7 @@ bool FsCtrlOperations::FsIntQuery()
     _fsCtrlImgInfo.sec_boot = fwQuery.sec_boot;
     _fsCtrlImgInfo.life_cycle = fwQuery.life_cycle;
     _fsCtrlImgInfo.encryption = fwQuery.encryption;
+    _fsCtrlImgInfo.ini_file_version = fwQuery.ini_file_version;
     std::vector<FwComponent> compsMap;
     if (!_fwCompsAccess->getFwComponents(compsMap, false))
     {
@@ -286,7 +291,8 @@ bool FsCtrlOperations::FsIntQuery()
     }
     DPRINTF(("mfsv_reg_supported = %d\n", mfsv_reg_supported));
 
-    if (_fsCtrlImgInfo.sec_boot == 1 && _fsCtrlImgInfo.life_cycle == GA_SECURED && mfsv_reg_supported == 1)
+    if (_fsCtrlImgInfo.sec_boot == 1 && CRSpaceRegisters::IsLifeCycleSecured(_fsCtrlImgInfo.life_cycle) &&
+        mfsv_reg_supported == 1)
     {
         _fsCtrlImgInfo.device_security_version_access_method = MFSV;
     }
@@ -435,9 +441,29 @@ bool FsCtrlOperations::FwQuery(fw_info_t* fwInfo,
     (void)verbose;
     memcpy(&(fwInfo->fw_info), &(_fwImgInfo.ext_info), sizeof(fw_info_com_t));
     memcpy(&(fwInfo->fs3_info), &(_fsCtrlImgInfo), sizeof(fs3_info_t));
-    fwInfo->fs3_info.fs3_uids_info.valid_field = 1;
+    fwInfo->fs3_info.fs3_uids_info.guid_format = IMAGE_LAYOUT_UIDS;
     fwInfo->fw_type = FwType();
 
+    if (isMultiAsicSystemComponent())
+    {
+        dm_dev_id_t dm_device_id = DeviceUnknown;
+        u_int32_t localPort = 0;
+        if (dm_get_device_id_offline(_hwDevId, fwInfo->fw_info.dev_rev, &dm_device_id) == ME_OK)
+        {
+            if (dm_dev_is_switch(dm_device_id))
+            { // local port 0 for switches is virtual, need to use any other port number
+                localPort = 1;
+            }
+        }
+
+        fwInfo->fs3_info.fs3_uids_info.guid_format = MULTI_ASIC_GUIDS;
+        if (!_fwCompsAccess->queryPGUID(fwInfo, localPort, 0, 0)) // this updates fwInfo, which contains the info
+                                                                     // flint query displays.
+        {
+            fwInfo->fs3_info.fs3_uids_info.guid_format = IMAGE_LAYOUT_UIDS;
+            return true;
+        }
+    }
     return true;
 }
 
@@ -830,6 +856,15 @@ bool FsCtrlOperations::burnEncryptedImage(FwOperations* imageOps, ExtBurnParams&
     return FwBurnAdvanced(imageOps, burnParams);
 }
 
+bool FsCtrlOperations::isMultiAsicSystemComponent()
+{
+    if (_hwDevId == QUANTUM3_HW_ID || _hwDevId == CX8_HW_ID)
+    {
+        return true;
+    }
+    return false;
+}
+
 bool FsCtrlOperations::_Burn(std::vector<u_int8_t> imageOps4MData,
                              ProgressCallBackAdvSt& progressCallBack,
                              FwComponent::comps_ids_t ComponentId)
