@@ -44,6 +44,7 @@
 #include "fs2_ops.h"
 #include "fsctrl_ops.h"
 #include "fs_comps_factory.h"
+#include "dev_mgt/tools_dev_types.h"
 
 #ifdef CABLES_SUPP
 #include "cablefw_ops.h"
@@ -98,12 +99,6 @@ int FwOperations::getFileSignature(const char* fname)
         return res;
     }
 
-    if (strlen((const char*)tmpb) < 4)
-    {
-        fclose(fin);
-        return res;
-    }
-
     if (!strncmp((char*)tmpb, "MTFW", 4) || FsCompsFactory::IsFsCompsFingerPrint(tmpb))
     {
         res = IMG_SIG_TYPE_BIN;
@@ -921,6 +916,28 @@ const char* file_handle_type_to_str(fw_hndl_type_t type)
     }
 }
 
+bool FwOperations::IsDeviceSupported(fw_ops_params_t& fwParams)
+{
+    mfile* mf = mopen_adv(fwParams.mstHndl, (MType)(MST_DEFAULT | MST_LINKX_CHIP));
+    if (!mf)
+    {
+        return false;
+    }
+
+    dm_dev_id_t devid_t = DeviceUnknown;
+    u_int32_t devid = 0;
+    u_int32_t revid = 0;
+    dm_get_device_id(mf, &devid_t, &devid, &revid);
+    if (dm_is_gpu(devid_t))
+    {
+        mclose(mf);
+        WriteToErrBuff(fwParams.errBuff, (char*)"GPUs are not supported.", fwParams.errBuffSize);
+        return false;
+    }
+    mclose(mf);
+    return true;
+}
+
 FwOperations* FwOperations::FwOperationsCreate(fw_ops_params_t& fwParams)
 {
     DPRINTF(("FwOperations::FwOperationsCreate\n"));
@@ -929,6 +946,10 @@ FwOperations* FwOperations::FwOperationsCreate(fw_ops_params_t& fwParams)
     FBase* ioAccess = (FBase*)NULL;
     FwCompsMgr* fwCompsAccess = (FwCompsMgr*)NULL;
     bool getFwFormatFromImg = false;
+    if (fwParams.hndlType == FHT_MST_DEV && !IsDeviceSupported(fwParams))
+    {
+        return (FwOperations*)NULL;
+    }
 #ifdef CABLES_SUPP
     if (fwParams.hndlType == FHT_CABLE_DEV)
     {
@@ -2542,9 +2563,8 @@ u_int8_t FwOperations::GetFwFormatFromHwDevID(u_int32_t hwDevId)
     else if (hwDevId == CX5_HW_ID || hwDevId == CX6_HW_ID || hwDevId == CX6DX_HW_ID || hwDevId == CX6LX_HW_ID ||
              hwDevId == CX7_HW_ID || hwDevId == CX8_HW_ID || hwDevId == BF_HW_ID || hwDevId == BF2_HW_ID ||
              hwDevId == BF3_HW_ID || hwDevId == BF4_HW_ID || hwDevId == QUANTUM_HW_ID || hwDevId == QUANTUM2_HW_ID ||
-             hwDevId == QUANTUM3_HW_ID || hwDevId == SPECTRUM4_HW_ID || hwDevId == SPECTRUM2_HW_ID ||
-             hwDevId == SPECTRUM3_HW_ID || hwDevId == GEARBOX_HW_ID || hwDevId == GB_MANAGER_HW_ID ||
-             hwDevId == ABIR_GB_HW_ID || hwDevId == ARCUSE_HW_ID)
+             hwDevId == SPECTRUM4_HW_ID || hwDevId == SPECTRUM3_HW_ID || hwDevId == SPECTRUM2_HW_ID ||
+             hwDevId == GEARBOX_HW_ID || hwDevId == GB_MANAGER_HW_ID || hwDevId == ABIR_GB_HW_ID)
     {
         return FS_FS4_GEN;
     }
@@ -2791,6 +2811,11 @@ bool FwOperations::VerifyBranchFormat(const char* vsdString)
     return false;
 }
 
+bool FwOperations::GetDtocAddress(u_int32_t& dTocAddress)
+{
+    return errmsg("GetDtocAddress not supported.");
+}
+
 bool FwOperations::PrintQuery()
 {
     return errmsg("PrintQuery not supported.");
@@ -2831,6 +2856,7 @@ bool FwOperations::IsExtendedGuidNumSupported()
     switch (_fwImgInfo.supportedHwId[0])
     {
         case SPECTRUM4_HW_ID:
+        case QUANTUM3_HW_ID:
             isSupported = true;
             break;
         default:
@@ -2872,7 +2898,8 @@ life_cycle_t CRSpaceRegisters::getLifeCycle()
     size_t lifeCycleAddress = 0;
     u_int8_t firstBit = 0;
     u_int8_t bitLen = 0;
-    u_int32_t lifeCycle;
+    life_cycle_t lifeCycle;
+    lifeCycle.version_field = 0;
 
     switch (_chip_type)
     {
@@ -2889,9 +2916,7 @@ life_cycle_t CRSpaceRegisters::getLifeCycle()
             bitLen = 2;
             break;
         case CT_CONNECTX7:
-        case CT_CONNECTX8:
         case CT_QUANTUM2:
-        case CT_QUANTUM3:
         case CT_BLUEFIELD3:
         case CT_BLUEFIELD4:
         case CT_SPECTRUM4:
@@ -2899,13 +2924,58 @@ life_cycle_t CRSpaceRegisters::getLifeCycle()
             firstBit = 4;
             bitLen = 2;
             break;
+        case CT_CONNECTX8:
+        case CT_QUANTUM3:
+        case CT_ARCUSE:
+            lifeCycleAddress = 0xf0000;
+            firstBit = 16;
+            bitLen = 3;
+            lifeCycle.version_field = 1;
+            break;
         default:
             throw logic_error("-E- life_cycle query is not implemented for the current device.");
             break;
     }
 
-    lifeCycle = getRegister(lifeCycleAddress);
-    return (life_cycle_t)getConsecutiveBits(lifeCycle, firstBit, bitLen);
+    lifeCycle.value = getConsecutiveBits(getRegister(lifeCycleAddress), firstBit, bitLen);
+    
+    return convertToLegacy(lifeCycle);
+}
+
+life_cycle_t CRSpaceRegisters::convertToLegacy(life_cycle_t lifeCycle)
+{
+    if (lifeCycle.version_field == 1)
+    {
+        switch (lifeCycle.value)
+        {
+            case life_cycle_fs5_t::PROD:
+                lifeCycle.value = life_cycle_fs4_t::GA_SECURED;
+                break;
+            case life_cycle_fs5_t::FAILURE_ANALYSIS:
+                lifeCycle.value = life_cycle_fs4_t::RMA;
+                break;
+            default:
+                break;
+        }
+    }
+    return lifeCycle;
+}
+
+bool CRSpaceRegisters::IsLifeCycleSecured(life_cycle_t life_cycle)
+{
+    if (life_cycle.version_field == 1)
+    {
+        return (life_cycle.value == PRE_PROD || life_cycle.value == PROD);
+    }
+    else
+    {
+        return life_cycle.value == GA_SECURED;
+    }
+}
+
+bool CRSpaceRegisters::IsLifeCycleSecured()
+{
+    return IsLifeCycleSecured(getLifeCycle());
 }
 
 int CRSpaceRegisters::getGlobalImageStatus()
@@ -2926,6 +2996,8 @@ int CRSpaceRegisters::getGlobalImageStatus()
             break;
         case CT_QUANTUM2:
         case CT_QUANTUM3:
+            global_image_status_address = 0x152080;
+            break;
         case CT_SPECTRUM4:
             global_image_status_address = 0xa1844;
             break;
