@@ -257,6 +257,7 @@ public:
                                             int buffSize = 0,
                                             bool ignore_crc_check = false);
     static FwOperations* FwOperationsCreate(fw_ops_params_t& fwParams);
+    static bool IsDeviceSupported(fw_ops_params_t& fwParams);
 
     static bool imageDevOperationsCreate(fw_ops_params_t& devParams,
                                          fw_ops_params_t& imgParams,
@@ -670,6 +671,7 @@ protected:
     virtual Tlv_Status_t GetTsObj(TimeStampIFC** tsObj);
     bool TestAndSetTimeStamp(FwOperations* imageOps);
     virtual bool VerifyBranchFormat(const char* vsdString);
+    virtual bool GetDtocAddress(u_int32_t& dTocAddress);
 
     // Protected Members
     FBase* _ioAccess;
@@ -744,7 +746,7 @@ protected:
     static const u_int32_t _fs4_magic_pattern[4];
 };
 
-class CRSpaceRegisters
+class MLXFWOP_API CRSpaceRegisters
 {
 public:
     CRSpaceRegisters(mfile* mf, chip_type_t chip_type);
@@ -752,6 +754,8 @@ public:
     int getGlobalImageStatus();
     life_cycle_t getLifeCycle();
     u_int32_t getSecurityVersion();
+    bool IsLifeCycleSecured();
+    static bool IsLifeCycleSecured(life_cycle_t life_cycle);
 
 private:
     mfile* _mf;
@@ -759,6 +763,7 @@ private:
     u_int32_t countSetBits(u_int32_t num);
     u_int32_t getConsecutiveBits(u_int32_t dword, u_int8_t firstBit, u_int8_t numOfBits);
     u_int32_t getRegister(u_int32_t address);
+    life_cycle_t convertToLegacy(life_cycle_t lifeCycle);
 };
 
 #endif // FW_ACCESS_H
