@@ -354,6 +354,14 @@ int mainEntry(int argc, char* argv[])
         if (cmd_params.device_names.size())
         {
             dev = new MlnxDev(cmd_params.device_names[i].c_str(), cmd_params.compare_ffv);
+            dm_dev_id_t deviceType = dev->getDeviceType();
+            if (dm_is_gpu(deviceType))
+            {
+                print_err("-E- GPU device is not supported\n");
+                delete dev;
+                continue;
+            }
+
             if (cmd_params.clear_semaphore)
             {
                 if (!dev->clearSemaphore())
@@ -373,6 +381,12 @@ int mainEntry(int argc, char* argv[])
         else
         {
             dev = new MlnxDev(&devsinfo[i], cmd_params.compare_ffv);
+            dm_dev_id_t deviceType = dev->getDeviceType();
+            if (dm_is_gpu(deviceType))
+            {
+                delete dev;
+                continue;
+            }
         }
         if (cmd_params.no_fw_ctrl)
         {
@@ -2370,7 +2384,15 @@ void printDeviceInfoQuery(int dev_index,
         }
         else if (devs[dev_index]->portOneType == MlnxDev::PORT_IB)
         {
-            print_out("  Base GUID:        %s\n", devs[dev_index]->guidPortOne.c_str());
+            if (!devs[dev_index]->baseGuid.empty() && devs[dev_index]->baseGuid != devs[dev_index]->guidPortOne)
+            {
+                print_out("  Base GUID:        %s\n", devs[dev_index]->baseGuid.c_str());
+                print_out("  Node GUID:        %s\n", devs[dev_index]->guidPortOne.c_str());
+            }
+            else
+            {
+                print_out("  Base GUID:        %s\n", devs[dev_index]->guidPortOne.c_str());
+            }
             if (devs[dev_index]->portTwoType == MlnxDev::PORT_ETH)
             {
                 print_out("  Base MAC:         %s\n", devs[dev_index]->macPortOne.c_str());
