@@ -378,9 +378,6 @@ public:
     bool checkGBPpaosDown();
     bool checkPaosDown();
     bool checkPpaosTestMode();
-    void getSltpParamsFromVector(std::vector<string> sltpParams);
-    void getprbsLanesFromParams(std::vector<string> prbsLanesParams);
-    std::vector<string> parseParamsFromLine(const string& ParamsLine);
     bool isSpect2WithGb();
     bool isIbLocalPortValid(u_int32_t localPort);
     void fillIbPortGroupMap(u_int32_t localPort, u_int32_t labelPort, u_int32_t group, bool splitReady);
@@ -397,7 +394,7 @@ public:
 
     // Mlxlink query functions
     virtual void showModuleInfo();
-    void prepareBerModuleInfoNdr(bool valid, const vector<AmberField>& moduleInfoFields);
+    void prepareBerModuleInfo(bool valid, const vector<AmberField>& moduleInfoFields);
     void pushSnrModuleInfoFields(bool valid);
     void runningVersion();
     virtual void operatingInfoPage();
@@ -430,12 +427,12 @@ public:
     void preparePowerAndCdrSection(bool valid);
     void prepareDDMSection(bool valid, bool isModuleExtSupported);
     virtual void preparePrtlSection();
-    void strToInt32(char* str, u_int32_t& value);
     template<typename T, typename Q>
     string getValueAndThresholdsStr(T value, Q lowTH, Q highTH);
     string getSltpFieldStr(const PRM_FIELD& field);
     void prepareSltpEdrHdrGen(vector<vector<string>>& sltpLanes, u_int32_t laneNumber);
     virtual void prepareSltpNdrGen(vector<vector<string>>& sltpLanes, u_int32_t laneNumber);
+    virtual void prepareSltpXdrGen(vector<vector<string>>& sltpLanes, u_int32_t laneNumber);
     virtual string getSltpHeader();
     void startSlrgPciScan(u_int32_t numOfLanesToUse);
     void initValidDPNList();
@@ -443,6 +440,7 @@ public:
     string getSupportedFecForSpeed(const string& speed);
     string fecMaskToUserInputStr(u_int32_t fecCapMask);
     string fecMaskToStr(u_int32_t mask);
+    void updateSwControlStatus();
 
     void showTestMode();
     void showTestModeBer();
@@ -519,10 +517,10 @@ public:
     // Mlxlink config functions
     void clearCounters();
     void sendPaos();
-    void handlePrbs();
+    virtual void handlePrbs();
     void sendPtys();
     virtual void sendPplm();
-    void sendSltp();
+    virtual void sendSltp();
     void sendPplr();
     void sendPepc();
     void setTxGroupMapping();
@@ -561,6 +559,7 @@ public:
     void checkPplmCap();
     string updateSltpEdrHdrFields();
     string updateSltpNdrFields();
+    virtual string updateSltpXdrFields();
     string getSltpStatus();
     void getSltpAlevOut(u_int32_t lane);
     void getSltpRegAndLeva(u_int32_t lane);
@@ -573,15 +572,12 @@ public:
     UserInput _userInput;
     dm_dev_id_t _devID;
     DPN _dpn;
+    vector<u_int32_t> _moduleLanesMapping;
     u_int32_t _numOfLanes;
     u_int32_t _numOfLanesPcie;
     u_int32_t _cableMediaType;
     u_int32_t _fecActive;
     u_int32_t _protoActive;
-    u_int32_t _uniqueCmds;
-    u_int32_t _uniqueCableCmds;
-    u_int32_t _uniquePcieCmds;
-    u_int32_t _networkCmds;
     u_int32_t _anDisable;
     u_int32_t _speedBerCsv;
     u_int32_t _cableIdentifier;
@@ -600,7 +596,6 @@ public:
     u_int32_t _linkSpeed;
     u_int32_t _groupOpcode;
     string _extAdbFile;
-    string _device;
     string _fwVersion;
     string _speedStrG;
     string _speedForce;
@@ -622,8 +617,9 @@ public:
     bool _ignorePortType;
     bool _ignorePortStatus;
     bool _isGboxPort;
+    bool _isSwControled;
     bool _ignoreIbFECCheck;
-    std::vector<std::string> _ptysSpeeds;
+    bool _isNVLINK;
     std::vector<PortGroup> _localPortsPerGroup;
     std::vector<DPN> _validDpns;
     string _allUnhandledErrors;
