@@ -34,7 +34,7 @@
 #define MLXLINK_ENUMS_H
 
 // Common definitions
-#define AMBER_VERSION "2.17"
+#define AMBER_VERSION "3.3"
 
 #define ACCESS_REG_MCIA "MCIA"
 #define ACCESS_REG_MDDQ "MDDQ"
@@ -68,10 +68,13 @@
 #define ACCESS_REG_PPAOS "PPAOS"
 #define ACCESS_REG_PPBMC "PPBMC"
 #define ACCESS_REG_PPCNT "PPCNT"
+#define ACCESS_REG_PPCR "PPCR"
 #define ACCESS_REG_PPHCR "PPHCR"
+#define ACCESS_REG_PPLL "PPLL"
 #define ACCESS_REG_PPLM "PPLM"
 #define ACCESS_REG_PPLR "PPLR"
 #define ACCESS_REG_PPRT "PPRT"
+#define ACCESS_REG_PPSLS "PPSLS"
 #define ACCESS_REG_PPTT "PPTT"
 #define ACCESS_REG_PREI "PREI"
 #define ACCESS_REG_PRTL "PRTL"
@@ -81,6 +84,7 @@
 #define ACCESS_REG_SLTP "SLTP"
 #define ACCESS_REG_SPAD "SPAD"
 #define ACCESS_REG_SPZR "SPZR"
+#define ACCESS_REG_MMCR "MMCR"
 // define all used regs above this line
 
 #define QSFP_CHANNELS 4
@@ -392,7 +396,7 @@
 
 #define DBN_TO_LOCAL_PORT_BASE 60
 
-#define MAX_LANES_NUMBER 4
+#define MAX_LANES_NUMBER 8
 #define MAX_DWORD_BLOCK_SIZE 32
 #define MAX_TX_GROUP_COUNT 10
 
@@ -578,9 +582,17 @@ enum PDDR_PAGES
     PDDR_OPERATIONAL_INFO_PAGE = 0,
     PDDR_TROUBLESHOOTING_INFO_PAGE = 1,
     PDDR_MODULE_INFO_PAGE = 3,
+    PDDR_MODULE_LINK_DOWN_INFO_PAGE = 6,
     PDDR_MODULE_LATCHED_FLAG_INFO_PAGE = 9,
 };
 
+enum DOWN_BLAME
+{
+    DOWN_BLAME_UNKOWN = 0,
+    DOWN_BLAME_LOCAL_PHY = 0x1,
+    DOWN_BLAME_REMOTE_PHY = 0x2,
+};
+
 enum GROUP_OPCODE
 {
     MONITOR_OPCODE = 0,
@@ -598,6 +610,7 @@ enum PPCNT_GROUPS
     PPCNT_PLR_GROUP = 0x22,
     PPCNT_HISTOGRAM_GROUP = 0x23,
     PPCNT_IB_PKTS_GROUP = 0x25,
+    PPCNT_IB_GEN_COUNTERS_GROUP = 0x26,
     PPCNT_ALL_GROUPS = 63,
 };
 
@@ -804,6 +817,24 @@ enum SLTP_NDR
     SLTP_NDR_LAST
 };
 
+enum SLTP_XDR
+{
+    SLTP_XDR_DRV_AMP,
+    SLTP_XDR_TAP0,
+    SLTP_XDR_TAP1,
+    SLTP_XDR_TAP2,
+    SLTP_XDR_TAP3,
+    SLTP_XDR_TAP4,
+    SLTP_XDR_TAP5,
+    SLTP_XDR_TAP6,
+    SLTP_XDR_TAP7,
+    SLTP_XDR_TAP8,
+    SLTP_XDR_TAP9,
+    SLTP_XDR_TAP10,
+    SLTP_XDR_TAP11,
+    SLTP_XDR_LAST
+};
+
 enum FEC_MODE
 {
     NO_FEC = 1,
@@ -966,7 +997,8 @@ enum OUI
 enum ProtoActive
 {
     IB = 1,
-    ETH = 4
+    ETH = 4,
+    NVLINK = 8
 };
 enum BAD_SET_STATUS_40_28NM
 {
@@ -1036,10 +1068,15 @@ enum EXT_ETHERNET_COMPLIANCE_CODE
     EXT_ETHERNET_COMPLIABCE_CODE_100GBASE_DR = 0X25,
     EXT_ETHERNET_COMPLIABCE_CODE_100G_FR = 0X26,
     EXT_ETHERNET_COMPLIABCE_CODE_100G_LR = 0X27,
+    EXT_ETHERNET_COMPLIABCE_CODE_400GBASE_SR4 = 0X29,
+    EXT_ETHERNET_COMPLIABCE_CODE_100GBASE_FR1 = 0X2A,
+    EXT_ETHERNET_COMPLIABCE_CODE_100GBASE_LR1 = 0X2B,
     EXT_ETHERNET_COMPLIABCE_CODE_ACC_10_6 = 0X30,
     EXT_ETHERNET_COMPLIABCE_CODE_AOC_10_6 = 0X31,
     EXT_ETHERNET_COMPLIABCE_CODE_ACC_10_4 = 0X32,
     EXT_ETHERNET_COMPLIABCE_CODE_AOC_10_4 = 0X33,
+    EXT_ETHERNET_COMPLIABCE_CODE_400GBASE_VR4 = 0X36,
+    EXT_ETHERNET_COMPLIABCE_CODE_400GBASE_CR4 = 0X3f,
     EXT_ETHERNET_COMPLIABCE_CODE_50GBASE_CR = 0X40,
     EXT_ETHERNET_COMPLIABCE_CODE_50GBASE_SR = 0X41,
     EXT_ETHERNET_COMPLIABCE_CODE_50GBASE_FR = 0X42,
@@ -1047,6 +1084,7 @@ enum EXT_ETHERNET_COMPLIANCE_CODE
     EXT_ETHERNET_COMPLIABCE_CODE_200GBASE_1550NM_PSM4 = 0X44,
     EXT_ETHERNET_COMPLIABCE_CODE_50GBASE_LR = 0X45,
     EXT_ETHERNET_COMPLIABCE_CODE_200GBASE_LR4 = 0X46,
+    EXT_ETHERNET_COMPLIABCE_CODE_400GBASE_DR4 = 0X47,
 };
 
 enum CMIS_IB_COMPLIANCE_CODE
@@ -1203,7 +1241,11 @@ enum CMIS_PASSIVE_COPPER_COMPLIANCE
     CMIS_COMPLIANCE_EDR = 0x30,
     CMIS_COMPLIANCE_HDR = 0x31,
     CMIS_COMPLIANCE_NDR = 0x32,
-    CMIS_COMPLIANCE_XDR = 0x33
+    CMIS_COMPLIANCE_XDR = 0x33,
+    CMIS_COMPLIANCE_100G_BASE_R1 = 0x46,
+    CMIS_COMPLIANCE_200G_BASE_R2 = 0x47,
+    CMIS_COMPLIANCE_400G_BASE_R4 = 0x48,
+    CMIS_COMPLIANCE_800G_BASE_R8 = 0x49
 };
 
 enum CMIS_MM_COMPLIANCE_CODE
@@ -1278,7 +1320,14 @@ enum PHY_MNGR_FSM_STATE
     PHY_MNGR_ACTIVE_LINKUP = 3,
     PHY_MNGR_CLOSE_PORT = 4,
     PHY_MNGR_PHYSICAL_LINKUP = 5,
-    PHY_MNGR_RX_DISABLE = 7
+    PHY_MNGR_SLEEP = 6,
+    PHY_MNGR_RX_DISABLE = 7,
+    PHY_MNGR_SIGNAL_DETECT = 8,
+    PHY_MNGR_RECEIVER_DETECT = 9,
+    PHY_MNGR_SYNC_PEER = 10,
+    PHY_MNGR_NEGOTIATION = 11,
+    PHY_MNGR_TRAINING = 12,
+    PHY_MNGR_SUB_FSM_ACTIVE = 13
 };
 
 enum IB_PHY_FSM_STATE
@@ -1290,7 +1339,8 @@ enum IB_PHY_FSM_STATE
     IB_AN_FSM_WAIT_RMT_TEST = 4,
     IB_AN_FSM_WAIT_CFG_ENHANCED = 5,
     IB_AN_FSM_CFG_IDLE = 6,
-    IB_AN_FSM_LINK_UP = 7
+    IB_AN_FSM_LINK_UP = 7,
+    IB_AN_FSM_POLLING = 8
 };
 
 enum TECH
@@ -1491,6 +1541,43 @@ enum IB_LINK_SPEED
     IB_LINK_SPEED_XDR = 0x100
 };
 
+// currently NVLink protocol suppots only XDR
+enum NVLINK_SPEED
+{
+    NVLINK_SPEED_SDR = 0x1,
+    NVLINK_SPEED_DDR = 0x2,
+    NVLINK_SPEED_QDR = 0x4,
+    NVLINK_SPEED_FDR10 = 0x8,
+    NVLINK_SPEED_FDR = 0x10,
+    NVLINK_SPEED_EDR = 0x20,
+    NVLINK_SPEED_HDR = 0x40,
+    NVLINK_SPEED_NDR = 0x80,
+    NVLINK_SPEED_XDR = 0x100
+};
+
+#define LINK_SPEED_200G_LANE IB_LINK_SPEED_XDR
+
+#define LINK_SPEED_100G_LANE (IB_LINK_SPEED_NDR | ETH_LINK_SPEED_100G_LANE)
+
+#define ETH_LINK_SPEED_100G_LANE                                                                  \
+    (ETH_LINK_SPEED_EXT_100GAUI_1 | ETH_LINK_SPEED_EXT_200GAUI_2 | ETH_LINK_SPEED_EXT_400GAUI_4 | \
+     ETH_LINK_SPEED_EXT_800GAUI_8)
+
+#define LINK_SPEED_50G_LANE (IB_LINK_SPEED_HDR | ETH_LINK_SPEED_50G_LANE)
+
+#define ETH_LINK_SPEED_50G_LANE                                                                  \
+    (ETH_LINK_SPEED_EXT_50GAUI_1 | ETH_LINK_SPEED_EXT_100GAUI_2 | ETH_LINK_SPEED_EXT_200GAUI_4 | \
+     ETH_LINK_SPEED_EXT_400GAUI_8)
+
+#define LINK_SPEED_25G_LANE (IB_LINK_SPEED_EDR | ETH_LINK_SPEED_25G_LANE)
+
+#define ETH_LINK_SPEED_25G_LANE                                                                              \
+    (ETH_LINK_SPEED_100G_CR4 | ETH_LINK_SPEED_100G_KR4 | ETH_LINK_SPEED_100G_LR4 | ETH_LINK_SPEED_100G_SR4 | \
+     ETH_LINK_SPEED_50G_KR2 | ETH_LINK_SPEED_50G_SR2 | ETH_LINK_SPEED_50G_CR2 | ETH_LINK_SPEED_25G_CR |      \
+     ETH_LINK_SPEED_25G_KR | ETH_LINK_SPEED_25G_SR | ETH_LINK_SPEED_50G_KR4)
+
+#define LINK_SPEED_ALL 0xffffffff
+
 enum PRBS_MODULATION
 {
     PRBS_NRZ = 0,
@@ -1572,6 +1659,7 @@ enum AMBER_SHEET
     AMBER_SHEET_TEST_MODE_MODULE_INFO = 14,
     AMBER_SHEET_PHY_DEBUG_INFO = 15,
     AMBER_SHEET_EXT_MODULE_STATUS = 16,
+    AMBER_SHEET_SERDES_5NM = 17,
     AMBER_SHEET_ALL // Keep this enum last
 };
 
@@ -1693,4 +1781,42 @@ enum PCIE_ERR_INJ_TYPE
     PCIE_ERR_TYPE_RECEIVER_ERROR = 101
 };
 
+enum LOCAL_REASON_OPCODE
+{
+    LOCAL_REASON_OPCODE_NO_LINK_DOWN_INDICAION = 0,
+    LOCAL_REASON_OPCODE_UNKWON_REASON = 0x1,
+    LOCAL_REASON_OPCODE_HI_SER_OR_HI_BER = 0x2,
+    LOCAL_REASON_OPCODE_BLOCK_LOCK_LOSS = 0x3,
+    LOCAL_REASON_OPCODE_ALIGNMENT_LOSS = 0x4,
+    LOCAL_REASON_OPCODE_FEC_SYNC_LOSS = 0x5,
+    LOCAL_REASON_OPCODE_PLL_SYNC_LOSS = 0x6,
+    LOCAL_REASON_OPCODE_FIFO_OVERFLOW = 0x7,
+    LOCAL_REASON_OPCODE_FALSE_SKIP_CONDITION = 0x8,
+    LOCAL_REASON_OPCODE_MINOR_ERROR_THRESHOLD_EXCEEDED = 0x9,
+    LOCAL_REASON_OPCODE_PHYSICAL_LAYER_RETRANSMISSION_TIMEOUT = 0xA,
+    LOCAL_REASON_OPCODE_HEARTBEAT_ERRORS = 0xB,
+    LOCAL_REASON_OPCODE_LINK_LAYER_CREDIT_MONITORING_WATCHDOG = 0xC,
+    LOCAL_REASON_OPCODE_LINK_LAYER_INTEGRITY_THRESHOLD_EXCEEDED = 0xD,
+    LOCAL_REASON_OPCODE_LINK_LAYER_BUFFER_OVERRUN = 0xE,
+    LOCAL_REASON_OPCODE_DOWN_BY_OUTBAND_COMMAND_WITH_HEALTHY_LINK = 0xF,
+    LOCAL_REASON_OPCODE_DOWN_BY_OUTBAND_COMMAND_FOR_LINK_WITH_HI_BER = 0x10,
+    LOCAL_REASON_OPCODE_DOWN_BY_INBAND_COMMAND_WITH_HEALTHY_LINK = 0x11,
+    LOCAL_REASON_OPCODE_DOWN_BY_INBAND_COMMAND_FOR_LINK_WITH_HI_BER = 0x12,
+    LOCAL_REASON_OPCODE_DOWN_BY_VERIFICATION_GW = 0x13,
+    LOCAL_REASON_OPCODE_RECEIVED_REMOTE_FAULT = 0x14,
+    LOCAL_REASON_OPCODE_RECEIVED_TS1 = 0x15,
+    LOCAL_REASON_OPCODE_DOWN_BY_MANAGEMENT_COMMAND = 0x16,
+    LOCAL_REASON_OPCODE_CABLE_WAS_UNPLUGGED = 0x17,
+    LOCAL_REASON_OPCODE_CABLE_ACCESS_ISSUE = 0x18,
+    LOCAL_REASON_OPCODE_THERMAL_SHUTDOWN = 0x19,
+    LOCAL_REASON_OPCODE_CURRENT_ISSUE = 0x1A,
+    LOCAL_REASON_OPCODE_POWER_BUDGET = 0x1B,
+    LOCAL_REASON_OPCODE_FAST_RECOVERY_RAW_BER = 0x1C,
+    LOCAL_REASON_OPCODE_FAST_RECOVERY_EFFECTIVE_BER = 0x1D,
+    LOCAL_REASON_OPCODE_FAST_RECOVERY_SYMBOL_BER = 0x1E,
+    LOCAL_REASON_OPCODE_FAST_RECOVERY_CREDIT_WATCHDOG = 0x1F,
+    LOCAL_REASON_OPCODE_TIMEOUT = 0x20,
+    LOCAL_REASON_OPCODE_RESERVED = 0xE4,
+};
+
 #endif /* MLXLINK_ENUMS_H */
