@@ -47,13 +47,6 @@ MlxlinkMaps* MlxlinkMaps::getInstance()
 
 void MlxlinkMaps::initPublicStrings()
 {
-    _berCollectTitle =
-      "Test Mode (Nominal/Corner/Drift),Protocol,Speed [Gb/s],Active FEC,Iteration Number,Device PN,FW Version,Device "
-      "ID,Port Number,Media,Cable PN,Length [m],Attenuation [dB],"
-      "Test time [Min],Raw Errors Lane 0,Raw Errors Lane 1,Raw Errors Lane 2,Raw Errors Lane 3,Raw Errors Lane 4,Raw "
-      "Errors Lane 5,Raw Errors Lane 6,Raw Errors Lane 7,Link Down,Total Raw BER,Raw BER limit,"
-      "Effective Errors,Effective BER,Result,System Voltage,Chip Start Temp,Chip End Temp,Module Start Temp,Module End "
-      "Temp,Active RTN,Device SN,Cable SN,RX End BW [Gb/s]";
     _showErrorsTitle = "Errors";
 }
 
@@ -65,10 +58,18 @@ void MlxlinkMaps::initPortStateMapping()
     _pmFsmState[PHY_MNGR_ACTIVE_LINKUP] = "Active";
     _pmFsmState[PHY_MNGR_CLOSE_PORT] = "Close port";
     _pmFsmState[PHY_MNGR_PHYSICAL_LINKUP] = "Physical LinkUp";
+    _pmFsmState[PHY_MNGR_SLEEP] = "Sleep";
     _pmFsmState[PHY_MNGR_RX_DISABLE] = "Rx disable";
+    _pmFsmState[PHY_MNGR_SIGNAL_DETECT] = "Signal detect";
+    _pmFsmState[PHY_MNGR_RECEIVER_DETECT] = "Receiver detect";
+    _pmFsmState[PHY_MNGR_SYNC_PEER] = "Sync peer";
+    _pmFsmState[PHY_MNGR_NEGOTIATION] = "Negotiation";
+    _pmFsmState[PHY_MNGR_TRAINING] = "Training";
+    _pmFsmState[PHY_MNGR_SUB_FSM_ACTIVE] = "SubFSM active";
 
     _networkProtocols[IB] = "InfiniBand";
     _networkProtocols[ETH] = "Ethernet";
+    _networkProtocols[NVLINK] = "NVLink";
 
     _ethANFsmState[0x0] = "ETH_AN_FSM_ENABLE";
     _ethANFsmState[0x1] = "ETH_AN_FSM_XMIT_DISABLE";
@@ -289,6 +290,7 @@ void MlxlinkMaps::ibSpeedMapping()
     _IBSpeed2gNum[IB_LINK_SPEED_EDR] = 100;
     _IBSpeed2gNum[IB_LINK_SPEED_HDR] = 200;
     _IBSpeed2gNum[IB_LINK_SPEED_NDR] = 400;
+    _IBSpeed2gNum[IB_LINK_SPEED_XDR] = 800;
 
     _IBSpeed2Str[IB_LINK_SPEED_SDR] = "IB-SDR";
     _IBSpeed2Str[IB_LINK_SPEED_DDR] = "IB-DDR";
@@ -298,6 +300,20 @@ void MlxlinkMaps::ibSpeedMapping()
     _IBSpeed2Str[IB_LINK_SPEED_EDR] = "IB-EDR";
     _IBSpeed2Str[IB_LINK_SPEED_HDR] = "IB-HDR";
     _IBSpeed2Str[IB_LINK_SPEED_NDR] = "IB-NDR";
+    _IBSpeed2Str[IB_LINK_SPEED_XDR] = "IB-XDR";
+}
+
+void MlxlinkMaps::nvlinkSpeedMapping()
+{
+  _NVLINKSpeed2Str[NVLINK_SPEED_SDR] = "NVLink-SDR";
+    _NVLINKSpeed2Str[NVLINK_SPEED_DDR] = "NVLink-DDR";
+    _NVLINKSpeed2Str[NVLINK_SPEED_QDR] = "NVLink-QDR";
+    _NVLINKSpeed2Str[NVLINK_SPEED_FDR10] = "NVLink-FDR10";
+    _NVLINKSpeed2Str[NVLINK_SPEED_FDR] = "NVLink-FDR";
+    _NVLINKSpeed2Str[NVLINK_SPEED_EDR] = "NVLink-EDR";
+    _NVLINKSpeed2Str[NVLINK_SPEED_HDR] = "NVLink-HDR";
+    _NVLINKSpeed2Str[NVLINK_SPEED_NDR] = "NVLink-NDR";
+    _NVLINKSpeed2Str[NVLINK_SPEED_XDR] = "NVLink-XDR";
 }
 
 void MlxlinkMaps::speedToLanesMapping()
@@ -357,6 +373,7 @@ void MlxlinkMaps::initPortSpeedMapping()
     ethSpeedMapping();
     extEthSpeedMapping();
     ibSpeedMapping();
+    nvlinkSpeedMapping();
     speedToLanesMapping();
 }
 
@@ -392,17 +409,20 @@ void MlxlinkMaps::initPrbsMapping()
     _prbsModesList[27] = "SQUARE_WAVE13";
     _prbsModesList[28] = "SQUARE_WAVE30";
 
-    _prbsLaneRateList[0] = "SDR (2.5 Gb/s)";
-    _prbsLaneRateList[1] = "DDR/5G (5 Gb/s)";
-    _prbsLaneRateList[2] = "QDR (10 Gb/s)";
-    _prbsLaneRateList[3] = "FDR10/10G/40G (10.3125 Gb/s)";
-    _prbsLaneRateList[4] = "FDR/14G (14.0625 Gb/s)";
-    _prbsLaneRateList[5] = "EDR/25G/50G/100G (25.78125 Gb/s)";
-    _prbsLaneRateList[6] = "1G (1.25 Gb/s)";
-    _prbsLaneRateList[7] = "XAUI/2.5G (3.125 Gb/s)";
-    _prbsLaneRateList[8] = "50GE-KR4/12.89G (12.89 Gb/s)";
-    _prbsLaneRateList[9] = "HDR/50G_1X/100G_2X/200G_4X/400G_8X (26.5625Gbd/53.125Gb/s)";
-    _prbsLaneRateList[10] = "NDR/100G_1X/200G_2X/400G_4X/800G_8X (53.125Gbd/106.25Gb/s)";
+    _prbsLaneRateList[0] = "2.5G";
+    _prbsLaneRateList[1] = "5G";
+    _prbsLaneRateList[2] = "10G";
+    _prbsLaneRateList[3] = "10.3125G";
+    _prbsLaneRateList[4] = "14.0625G";
+    _prbsLaneRateList[5] = "25.78125G";
+    _prbsLaneRateList[6] = "53.125G";
+    _prbsLaneRateList[7] = "106.25G";
+    _prbsLaneRateList[8] = "212.5G";
+    _prbsLaneRateList[9] = "N/A";
+    _prbsLaneRateList[10] = "1.25G";
+    _prbsLaneRateList[11] = "3.125G";
+    _prbsLaneRateList[12] = "12.89G";
+
     // 1G
     _prbsLaneRate["1G"] = {LANE_RATE_1G_CAP, PRBS_1G};
     // 2.5G
@@ -452,23 +472,27 @@ void MlxlinkMaps::initPrbsMapping()
     _prbsLaneRate["200G_2X"] = {LANE_RATE_NDR_CAP, PRBS_NDR};
     _prbsLaneRate["400G_4X"] = {LANE_RATE_NDR_CAP, PRBS_NDR};
     _prbsLaneRate["800G_8X"] = {LANE_RATE_NDR_CAP, PRBS_NDR};
+    // XDR
+    _prbsLaneRate["IB-XDR"] = {LANE_RATE_XDR_CAP, PRBS_XDR};
+    _prbsLaneRate["XDR"] = {LANE_RATE_XDR_CAP, PRBS_XDR};
 
     _prbsRxTuningStatus[0] = "PRBS mode tuning was not performed.";
     _prbsRxTuningStatus[1] = "Performing PRBS mode tuning.";
     _prbsRxTuningStatus[2] = "PRBS mode tuning completed.";
     _prbsRxTuningStatus[3] = "Signal Detect in progress.";
 
-    _prbsLaneRateCap[0x1] = "1G (1.25 Gb/s)";
-    _prbsLaneRateCap[0x2] = "SDR (2.5 Gb/s)";
-    _prbsLaneRateCap[0x4] = "XAUI/2.5G (3.125 Gb/s)";
-    _prbsLaneRateCap[0x8] = "DDR/5G (5 Gb/s)";
-    _prbsLaneRateCap[0x10] = "QDR (10 Gb/s)";
-    _prbsLaneRateCap[0x20] = "FDR10/10G/40G (10.3125 Gb/s)";
-    _prbsLaneRateCap[0x40] = "FDR/14G (14.0625 Gb/s)";
-    _prbsLaneRateCap[0x80] = "EDR/25G/50G/100G (25.78125 Gb/s)";
-    _prbsLaneRateCap[0x100] = "50GE-KR4/12.89G (12.89 Gb/s)";
-    _prbsLaneRateCap[0x200] = "HDR/50G/100G/200G/400G (26.5625Gbd/53.125Gb/s)";
-    _prbsLaneRateCap[0x400] = "NDR/100G/200G/400G/800G (53.125Gbd/106.25Gb/s)";
+    _prbsLaneRateCap[LANE_RATE_1G_CAP] = "1G (1.25 Gb/s)";
+    _prbsLaneRateCap[LANE_RATE_SDR_CAP] = "SDR (2.5 Gb/s)";
+    _prbsLaneRateCap[LANE_RATE_XAUI_CAP] = "XAUI/2.5G (3.125 Gb/s)";
+    _prbsLaneRateCap[LANE_RATE_DDR_CAP] = "DDR/5G (5 Gb/s)";
+    _prbsLaneRateCap[LANE_RATE_QDR_CAP] = "QDR (10 Gb/s)";
+    _prbsLaneRateCap[LANE_RATE_FDR10_CAP] = "FDR10/10G/40G (10.3125 Gb/s)";
+    _prbsLaneRateCap[LANE_RATE_FDR_CAP] = "FDR/14G (14.0625 Gb/s)";
+    _prbsLaneRateCap[LANE_RATE_EDR_CAP] = "EDR/25G/50G/100G (25.78125 Gb/s)";
+    _prbsLaneRateCap[LANE_RATE_50G_CAP] = "50GE-KR4/12.89G (12.89 Gb/s)";
+    _prbsLaneRateCap[LANE_RATE_HDR_CAP] = "HDR/50G/100G/200G/400G (26.5625Gbd/53.125Gb/s)";
+    _prbsLaneRateCap[LANE_RATE_NDR_CAP] = "NDR/100G/200G/400G/800G (53.125Gbd/106.25Gb/s)";
+    _prbsLaneRateCap[LANE_RATE_XDR_CAP] = "XDR (106.25Gbd/212.5Gb/s)";
 
     _prbsLockStatus[0] = "Not locked";
     _prbsLockStatus[1] = "Locked";
@@ -580,28 +604,30 @@ void MlxlinkMaps::initLinkDownInfoMapping()
 
 void MlxlinkMaps::initSltpStatusMapping()
 {
-    _SltpEdrParams[SLTP_EDR_POLARITY] = PRM_FIELD{"polarity", "Pol", FIELD_ACCESS_RW, false};
-    _SltpEdrParams[SLTP_EDR_OB_TAP0] = PRM_FIELD{"ob_tap0", "tap0", FIELD_ACCESS_RW, false};
-    _SltpEdrParams[SLTP_EDR_OB_TAP1] = PRM_FIELD{"ob_tap1", "tap1", FIELD_ACCESS_RW, false};
-    _SltpEdrParams[SLTP_EDR_OB_TAP2] = PRM_FIELD{"ob_tap2", "tap2", FIELD_ACCESS_RW, false};
-    _SltpEdrParams[SLTP_EDR_OB_BIAS] = PRM_FIELD{"ob_bias", "bias", FIELD_ACCESS_RW, false};
-    _SltpEdrParams[SLTP_EDR_OB_PREEMP_MODE] = PRM_FIELD{"ob_preemp_mode", "preemp_mode", FIELD_ACCESS_RW, false};
-    _SltpEdrParams[SLTP_EDR_OB_REG] = PRM_FIELD{"ob_reg", "reg", FIELD_ACCESS_ADVANCED, false};
-    _SltpEdrParams[SLTP_EDR_OB_LEVA] = PRM_FIELD{"ob_leva", "leva", FIELD_ACCESS_ADVANCED, false};
+    _SltpEdrParams[SLTP_EDR_POLARITY] = PRM_FIELD{"polarity", "Pol", FIELD_ACCESS_RW, false, LINK_SPEED_ALL};
+    _SltpEdrParams[SLTP_EDR_OB_TAP0] = PRM_FIELD{"ob_tap0", "tap0", FIELD_ACCESS_RW, false, LINK_SPEED_ALL};
+    _SltpEdrParams[SLTP_EDR_OB_TAP1] = PRM_FIELD{"ob_tap1", "tap1", FIELD_ACCESS_RW, false, LINK_SPEED_ALL};
+    _SltpEdrParams[SLTP_EDR_OB_TAP2] = PRM_FIELD{"ob_tap2", "tap2", FIELD_ACCESS_RW, false, LINK_SPEED_ALL};
+    _SltpEdrParams[SLTP_EDR_OB_BIAS] = PRM_FIELD{"ob_bias", "bias", FIELD_ACCESS_RW, false, LINK_SPEED_ALL};
+    _SltpEdrParams[SLTP_EDR_OB_PREEMP_MODE] =
+      PRM_FIELD{"ob_preemp_mode", "preemp_mode", FIELD_ACCESS_RW, false, LINK_SPEED_ALL};
+    _SltpEdrParams[SLTP_EDR_OB_REG] = PRM_FIELD{"ob_reg", "reg", FIELD_ACCESS_ADVANCED, false, LINK_SPEED_ALL};
+    _SltpEdrParams[SLTP_EDR_OB_LEVA] = PRM_FIELD{"ob_leva", "leva", FIELD_ACCESS_ADVANCED, false, LINK_SPEED_ALL};
 
-    _SltpHdrParams[SLTP_HDR_PRE_2_TAP] = PRM_FIELD{"pre_2_tap", "pre2Tap", FIELD_ACCESS_RW, true};
-    _SltpHdrParams[SLTP_HDR_PRE_TAP] = PRM_FIELD{"pre_tap", "preTap", FIELD_ACCESS_RW, true};
-    _SltpHdrParams[SLTP_HDR_MAIN_TAP] = PRM_FIELD{"main_tap", "mainTap", FIELD_ACCESS_RW, true};
-    _SltpHdrParams[SLTP_HDR_POST_TAP] = PRM_FIELD{"post_tap", "postTap", FIELD_ACCESS_RW, true};
-    _SltpHdrParams[SLTP_HDR_OB_M2LP] = PRM_FIELD{"ob_m2lp", "m2lp", FIELD_ACCESS_RW, true};
-    _SltpHdrParams[SLTP_HDR_OB_AMP] = PRM_FIELD{"ob_amp", "amp", FIELD_ACCESS_RW, false};
-    _SltpHdrParams[SLTP_HDR_OB_ALEV_OUT] = PRM_FIELD{"ob_alev_out", "alev_out", FIELD_ACCESS_W, false};
+    _SltpHdrParams[SLTP_HDR_PRE_2_TAP] = PRM_FIELD{"pre_2_tap", "pre2Tap", FIELD_ACCESS_RW, true, LINK_SPEED_ALL};
+    _SltpHdrParams[SLTP_HDR_PRE_TAP] = PRM_FIELD{"pre_tap", "preTap", FIELD_ACCESS_RW, true, LINK_SPEED_ALL};
+    _SltpHdrParams[SLTP_HDR_MAIN_TAP] = PRM_FIELD{"main_tap", "mainTap", FIELD_ACCESS_RW, true, LINK_SPEED_ALL};
+    _SltpHdrParams[SLTP_HDR_POST_TAP] = PRM_FIELD{"post_tap", "postTap", FIELD_ACCESS_RW, true, LINK_SPEED_ALL};
+    _SltpHdrParams[SLTP_HDR_OB_M2LP] = PRM_FIELD{"ob_m2lp", "m2lp", FIELD_ACCESS_RW, true, LINK_SPEED_ALL};
+    _SltpHdrParams[SLTP_HDR_OB_AMP] = PRM_FIELD{"ob_amp", "amp", FIELD_ACCESS_RW, false, LINK_SPEED_ALL};
+    _SltpHdrParams[SLTP_HDR_OB_ALEV_OUT] = PRM_FIELD{"ob_alev_out", "alev_out", FIELD_ACCESS_W, false, LINK_SPEED_ALL};
 
-    _SltpNdrParams[SLTP_NDR_FIR_PRE3] = PRM_FIELD{"fir_pre3", "fir_pre3", FIELD_ACCESS_RW, true};
-    _SltpNdrParams[SLTP_NDR_FIR_PRE2] = PRM_FIELD{"fir_pre2", "fir_pre2", FIELD_ACCESS_RW, true};
-    _SltpNdrParams[SLTP_NDR_FIR_PRE1] = PRM_FIELD{"fir_pre1", "fir_pre1", FIELD_ACCESS_RW, true};
-    _SltpNdrParams[SLTP_NDR_FIR_MAIN] = PRM_FIELD{"fir_main", "fir_main", FIELD_ACCESS_RW, true};
-    _SltpNdrParams[SLTP_NDR_FIR_POST1] = PRM_FIELD{"fir_post1", "fir_post1", FIELD_ACCESS_RW, true};
+    _SltpNdrParams[SLTP_NDR_FIR_PRE3] = PRM_FIELD{"fir_pre3", "fir_pre3", FIELD_ACCESS_RW, true, LINK_SPEED_100G_LANE};
+    _SltpNdrParams[SLTP_NDR_FIR_PRE2] =
+      PRM_FIELD{"fir_pre2", "fir_pre2", FIELD_ACCESS_RW, true, LINK_SPEED_100G_LANE | LINK_SPEED_50G_LANE};
+    _SltpNdrParams[SLTP_NDR_FIR_PRE1] = PRM_FIELD{"fir_pre1", "fir_pre1", FIELD_ACCESS_RW, true, LINK_SPEED_ALL};
+    _SltpNdrParams[SLTP_NDR_FIR_MAIN] = PRM_FIELD{"fir_main", "fir_main", FIELD_ACCESS_RW, true, LINK_SPEED_ALL};
+    _SltpNdrParams[SLTP_NDR_FIR_POST1] = PRM_FIELD{"fir_post1", "fir_post1", FIELD_ACCESS_RW, true, LINK_SPEED_ALL};
 
     _SLTP7BadSetStatus2Str[BAD_STAT_7NM_INVALID_PRE3] = "pre3 is out of range";
     _SLTP7BadSetStatus2Str[BAD_STAT_7NM_INVALID_PRE2] = "pre2 is out of range";
@@ -637,6 +663,7 @@ void MlxlinkMaps::cmisIbComlianceMapping()
     _cableComplianceCmisIb[CMIS_IB_COMPLIANCE_CODE_EDR] = "EDR";
     _cableComplianceCmisIb[CMIS_IB_COMPLIANCE_CODE_HDR] = "HDR";
     _cableComplianceCmisIb[CMIS_IB_COMPLIANCE_CODE_NDR] = "NDR";
+    _cableComplianceCmisIb[CMIS_IB_COMPLIANCE_CODE_XDR] = "XDR";
 }
 
 void MlxlinkMaps::cimsCableBreakoutMapping()
@@ -644,7 +671,7 @@ void MlxlinkMaps::cimsCableBreakoutMapping()
     _cimsCableBreakout[CMIS_CABLE_BREAKOUT_UNSPECIFIED] = "Unspecified";
     _cimsCableBreakout[CMIS_CABLE_BREAKOUT_QSFPDD_to_QSFPDD] = "X to X";
     _cimsCableBreakout[CMIS_CABLE_BREAKOUT_QSFPDD_to_2QSFP_or_2QSFPDD] = "X to 2xQSFP or 2xX (depopulated / 4 lanes)";
-    _cimsCableBreakout[CMIS_CABLE_BREAKOUT_QSFPDD_to_4SFPDD_or_4QSFP] = "X to 4xSFP-DD or 4xX (depopulated / 2 lanes)";
+    _cimsCableBreakout[CMIS_CABLE_BREAKOUT_QSFPDD_to_4SFPDD_or_4QSFP] = "X to 4xDSFP or 4xQSFP (depopulated / 2 lanes)";
     _cimsCableBreakout[CMIS_CABLE_BREAKOUT_QSFPDD_to_8SFP] = "X to 8xSFP";
     _cimsCableBreakout[CMIS_CABLE_BREAKOUT_QSFPDD_to_QSFP_or_QSFPDD] =
       "X (depopulated / 4 lanes) to QSFP or X (depopulated / 4 lanes)";
@@ -1049,6 +1076,10 @@ void MlxlinkMaps::extComplianceMapping()
     _cableComplianceExt[EXT_ETHERNET_COMPLIABCE_CODE_100GBASE_DR] = "100GBASE-DR, with CAUI-4 without FEC";
     _cableComplianceExt[EXT_ETHERNET_COMPLIABCE_CODE_100G_FR] = "100G-FR, with CAUI-4 without FEC";
     _cableComplianceExt[EXT_ETHERNET_COMPLIABCE_CODE_100G_LR] = "100G-LR, with CAUI-4 without FEC";
+    _cableComplianceExt[EXT_ETHERNET_COMPLIABCE_CODE_400GBASE_SR4] = "100GBASE-SR1, 200GBASE-SR2 or 400GBASE-SR4";
+    _cableComplianceExt[EXT_ETHERNET_COMPLIABCE_CODE_100GBASE_FR1] = "100GBASE-FR1 or 400GBASE-DR4-2";
+    _cableComplianceExt[EXT_ETHERNET_COMPLIABCE_CODE_100GBASE_LR1] = "100GBASE-LR1";
+
     _cableComplianceExt[EXT_ETHERNET_COMPLIABCE_CODE_ACC_10_6] =
       "Active Copper Cable with 50GAUI, 100GAUI-2 or 200GAUI-4 C2M. "
       "Providing a worst BER of 10^(-6) or below";
@@ -1063,6 +1094,8 @@ void MlxlinkMaps::extComplianceMapping()
       "Active Optical Cable with 50GAUI, 100GAUI-2 or 200GAUI-4 C2M. "
       "Providing a worst BER of 2.6x10^(-4) for AOC, 10^(-5) for AUI, "
       "or below";
+    _cableComplianceExt[EXT_ETHERNET_COMPLIABCE_CODE_400GBASE_VR4] = "100GBASE-VR1, 200GBASE-VR2 or 400GBASE-VR4";
+    _cableComplianceExt[EXT_ETHERNET_COMPLIABCE_CODE_400GBASE_CR4] = "100GBASE-CR1, 200GBASE-CR2 or 400GBASE-CR4";
     _cableComplianceExt[EXT_ETHERNET_COMPLIABCE_CODE_50GBASE_CR] = "50GBASE-CR, 100GBASE-CR2, or 200GBASE-CR4";
     _cableComplianceExt[EXT_ETHERNET_COMPLIABCE_CODE_50GBASE_SR] = "50GBASE-SR, 100GBASE-SR2, or 200GBASE-SR4";
     _cableComplianceExt[EXT_ETHERNET_COMPLIABCE_CODE_50GBASE_FR] = "50GBASE-FR or 200GBASE-DR4";
@@ -1070,6 +1103,7 @@ void MlxlinkMaps::extComplianceMapping()
     _cableComplianceExt[EXT_ETHERNET_COMPLIABCE_CODE_200GBASE_1550NM_PSM4] = "200G 1550 nm PSM4";
     _cableComplianceExt[EXT_ETHERNET_COMPLIABCE_CODE_50GBASE_LR] = "50GBASE-LR";
     _cableComplianceExt[EXT_ETHERNET_COMPLIABCE_CODE_200GBASE_LR4] = "200GBASE-LR4";
+    _cableComplianceExt[EXT_ETHERNET_COMPLIABCE_CODE_400GBASE_DR4] = "400GBASE-DR4, 400GAUI-4 C2M";
 }
 
 void MlxlinkMaps::hostComplianceMapping()
@@ -1117,6 +1151,11 @@ void MlxlinkMaps::hostComplianceMapping()
     _cmisHostCompliance[CMIS_COMPLIANCE_EDR] = "IB EDR";
     _cmisHostCompliance[CMIS_COMPLIANCE_HDR] = "IB HDR";
     _cmisHostCompliance[CMIS_COMPLIANCE_NDR] = "IB NDR";
+    _cmisHostCompliance[CMIS_COMPLIANCE_XDR] = "IB XDR";
+    _cmisHostCompliance[CMIS_COMPLIANCE_100G_BASE_R1] = "100GBASE-CR1";
+    _cmisHostCompliance[CMIS_COMPLIANCE_200G_BASE_R2] = "200GBASE-CR2";
+    _cmisHostCompliance[CMIS_COMPLIANCE_400G_BASE_R4] = "400GBASE-CR4";
+    _cmisHostCompliance[CMIS_COMPLIANCE_800G_BASE_R8] = "800G-ETC-CR8 or 800GBASE-CR8";
 }
 
 void MlxlinkMaps::mediaComplianceMapping()
@@ -1191,6 +1230,31 @@ void MlxlinkMaps::activeComplianceMapping()
     _activeCableCompliance[4] = "Active Cable assembly with BER < 10-6";
 }
 
+void MlxlinkMaps::pcieEnumMapping()
+{
+    _pcieErrType[PCIE_ERR_TYPE_ABORT] = PcieErrType{"ABORT", 0, 0, 0, false, false, false, false, false, false, ""};
+    _pcieErrType[PCIE_ERR_TYPE_BAD_DLLP_LCRC] = PcieErrType{
+      "BAD_DLLP_LCRC", 100000, 1, PCIE_MAX_DURATION_HW_COUNTERS, true, false, false, false, false, false, "Packet"};
+    _pcieErrType[PCIE_ERR_TYPE_BAD_TLP_LCRC] = PcieErrType{
+      "BAD_TLP_LCRC", 100000, 1, PCIE_MAX_DURATION_HW_COUNTERS, true, true, false, false, false, false, "Packet"};
+    _pcieErrType[PCIE_ERR_TYPE_BAD_TLP_ECRC] = PcieErrType{
+      "BAD_TLP_ECRC", 100000, 1, PCIE_MAX_DURATION_HW_COUNTERS, true, true, false, false, false, false, "Packet"};
+    _pcieErrType[PCIE_ERR_TYPE_ERR_MSG] =
+      PcieErrType{"ERR_MSG", 0, 1, PCIE_MAX_DURATION, true, true, false, false, false, false, "Packet"};
+    _pcieErrType[PCIE_ERR_TYPE_MALFORMED_TLP] =
+      PcieErrType{"MALFORMED_TLP", 0, 1, PCIE_MAX_DURATION, true, false, false, false, false, true, "Packet"};
+    _pcieErrType[PCIE_ERR_TYPE_POISONED_TLP] =
+      PcieErrType{"POISONED_TLP", 0, 1, PCIE_MAX_DURATION, true, false, false, false, false, true, "Packet"};
+    _pcieErrType[PCIE_ERR_TYPE_UNEXPECTED_CPL] =
+      PcieErrType{"UNEXPECTED_CPL", 0, 1, PCIE_MAX_DURATION, true, true, true, true, false, true, "Packet"};
+    _pcieErrType[PCIE_ERR_TYPE_ACS_VIOLATION] =
+      PcieErrType{"ACS_VIOLATION", 0, 1, PCIE_MAX_DURATION, true, false, false, false, false, false, "Packet"};
+    _pcieErrType[PCIE_ERR_TYPE_SURP_LINK_DOWN] =
+      PcieErrType{"SURPRISE_LINK_DOWN", 100000, 1, PCIE_MAX_DURATION, true, true, false, false, false, false, "usec"};
+    _pcieErrType[PCIE_ERR_TYPE_RECEIVER_ERROR] =
+      PcieErrType{"RECEIVER_ERROR", 100000, 0, PCIE_MAX_DURATION, true, false, false, false, false, false, "usec"};
+}
+
 void MlxlinkMaps::initCableComplianceMapping()
 {
     qsfpComlianceMapping();
@@ -1216,6 +1280,7 @@ void MlxlinkMaps::initCableComplianceMapping()
     errorCodeResMapping();
     techMapping();
     modulePrbsMapping();
+    pcieEnumMapping();
 }
 
 void MlxlinkMaps::initCableTechnologyMapping()
@@ -1286,6 +1351,55 @@ void MlxlinkMaps::initCablePowerClassMapping()
     _sfpddPowerClassToValue[POWER_CLASS5] = 5.0;
 }
 
+void MlxlinkMaps::initEnhancedDebugMapping()
+{
+    _downBlame[DOWN_BLAME_UNKOWN] = "Unknown";
+    _downBlame[DOWN_BLAME_LOCAL_PHY] = "Local_phy";
+    _downBlame[DOWN_BLAME_REMOTE_PHY] = "Remote_phy";
+
+    _localReasonOpcode[LOCAL_REASON_OPCODE_NO_LINK_DOWN_INDICAION] = "No_link_down_indication";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_UNKWON_REASON] = "Unknown_reason";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_HI_SER_OR_HI_BER] = "Hi_SER_or_Hi_BER";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_BLOCK_LOCK_LOSS] = "Block_Lock_loss";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_ALIGNMENT_LOSS] = "Alignment_loss";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_FEC_SYNC_LOSS] = "FEC_sync_loss";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_PLL_SYNC_LOSS] = "PLL_lock_loss";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_FIFO_OVERFLOW] = "FIFO_overflow";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_FALSE_SKIP_CONDITION] = "false_SKIP_condition";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_MINOR_ERROR_THRESHOLD_EXCEEDED] = "Minor_Error_threshold_exceeded";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_PHYSICAL_LAYER_RETRANSMISSION_TIMEOUT] =
+      "Physical_layer_retransmission_timeout";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_HEARTBEAT_ERRORS] = "Heartbeat_errors";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_LINK_LAYER_CREDIT_MONITORING_WATCHDOG] =
+      "Link_Layer_credit_monitoring_watchdog";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_LINK_LAYER_INTEGRITY_THRESHOLD_EXCEEDED] =
+      "Link_Layer_integrity_threshold_exceeded";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_LINK_LAYER_BUFFER_OVERRUN] = "Link_Layer_buffer_overrun";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_DOWN_BY_OUTBAND_COMMAND_WITH_HEALTHY_LINK] =
+      "Down_by_outband_command_with_healthy_link";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_DOWN_BY_OUTBAND_COMMAND_FOR_LINK_WITH_HI_BER] =
+      "Down_by_outband_command_for_link_with_hi_ber";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_DOWN_BY_INBAND_COMMAND_WITH_HEALTHY_LINK] =
+      "Down_by_inband_command_with_healthy_link";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_DOWN_BY_INBAND_COMMAND_FOR_LINK_WITH_HI_BER] =
+      "Down_by_inband_command_for_link_with_hi_ber";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_DOWN_BY_VERIFICATION_GW] = "Down_by_verification_GW";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_RECEIVED_REMOTE_FAULT] = "Received_Remote_Fault";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_RECEIVED_TS1] = "Received_TS1";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_DOWN_BY_MANAGEMENT_COMMAND] = "Down_by_management_command";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_CABLE_WAS_UNPLUGGED] = "Cable_was_unplugged";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_CABLE_ACCESS_ISSUE] = "Cable_access_issue";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_THERMAL_SHUTDOWN] = "Thermal_shutdown";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_CURRENT_ISSUE] = "Current_issue";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_POWER_BUDGET] = "Power_budget";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_FAST_RECOVERY_EFFECTIVE_BER] = "Fast_recovery_raw_ber";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_FAST_RECOVERY_EFFECTIVE_BER] = "Fast_recovery_effective_ber";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_FAST_RECOVERY_SYMBOL_BER] = "Fast_recovery_symbol_ber";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_FAST_RECOVERY_CREDIT_WATCHDOG] = "Fast_recovery_credit_watchdog";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_TIMEOUT] = "Timeout";
+    _localReasonOpcode[LOCAL_REASON_OPCODE_RESERVED] = "N/A";
+}
+
 MlxlinkMaps::MlxlinkMaps()
 {
     initPublicStrings();
@@ -1299,6 +1413,7 @@ MlxlinkMaps::MlxlinkMaps()
     initCableComplianceMapping();
     initCableTechnologyMapping();
     initCablePowerClassMapping();
+    initEnhancedDebugMapping();
     phyHstFsmHdrStateMapping();
 }
 
