@@ -43,8 +43,8 @@
 #include <sstream>
 #include <iterator>
 #include <vector>
-#include <mlxreg/mlxreg_lib.h>
-#include <mlxreg/mlxreg_parser.h>
+#include <mlxreg/mlxreg_lib/mlxreg_lib.h>
+#include <mlxreg/mlxreg_lib/mlxreg_parser.h>
 #include "mlxlink_user_input.h"
 #include "printutil/mlxlink_cmd_print.h"
 #include "mlxlink_enums.h"
@@ -109,10 +109,38 @@ struct CAP_VALUE
 
 struct PRM_FIELD
 {
+    PRM_FIELD()
+    {
+        prmField = "";
+        uiField = "";
+        fieldAccess = 0;
+        isSigned = false;
+        validationMask = 0;
+    }
+
+    PRM_FIELD(string _prmField, string _uiField, u_int32_t _fieldAccess, bool _isSigned)
+    {
+        prmField = _prmField;
+        uiField = _uiField;
+        fieldAccess = _fieldAccess;
+        isSigned = _isSigned;
+        validationMask = 0;
+    }
+
+    PRM_FIELD(string _prmField, string _uiField, u_int32_t _fieldAccess, bool _isSigned, u_int32_t _validationMask)
+    {
+        prmField = _prmField;
+        uiField = _uiField;
+        fieldAccess = _fieldAccess;
+        isSigned = _isSigned;
+        validationMask = _validationMask;
+    }
+
     string prmField;
     string uiField;
     u_int32_t fieldAccess;
     bool isSigned;
+    u_int32_t validationMask;
 };
 
 class MlxlinkMaps
@@ -126,6 +154,7 @@ private:
     void ethSpeedMapping();
     void extEthSpeedMapping();
     void ibSpeedMapping();
+    void nvlinkSpeedMapping();
     void speedToLanesMapping();
     void initPortSpeedMapping();
     void initPrbsMapping();
@@ -160,6 +189,8 @@ private:
     void linkPeerMaxSpeedMapping();
     void portStateMapping();
     void techMapping();
+    void pcieEnumMapping();
+    void initEnhancedDebugMapping();
 
 public:
     static MlxlinkMaps* getInstance();
@@ -199,6 +230,7 @@ public:
     std::map<u_int32_t, std::string> _moduleRxAmpCap;
     std::map<u_int32_t, std::string> _pepcStatus;
     std::map<u_int32_t, string> _IBSpeed2Str;
+    std::map<u_int32_t, string> _NVLINKSpeed2Str;
     std::map<u_int32_t, string> _EthExtSpeed2Str;
     std::map<u_int32_t, u_int32_t> _IBSpeed2gNum;
     std::map<u_int32_t, u_int32_t> _ETHSpeed2gNum;
@@ -212,6 +244,7 @@ public:
     std::map<u_int32_t, PRM_FIELD> _SltpEdrParams;
     std::map<u_int32_t, PRM_FIELD> _SltpHdrParams;
     std::map<u_int32_t, PRM_FIELD> _SltpNdrParams;
+    std::map<u_int32_t, PRM_FIELD> _SltpXdrParams;
     std::map<u_int32_t, std::string> _ethANFsmState;
     std::map<u_int32_t, std::string> _fecModeActive;
     std::map<u_int32_t, pair<string, string>> _fecModeMask;
@@ -278,9 +311,9 @@ public:
     std::map<u_int32_t, std::string> _pllUglState;
     std::map<u_int32_t, std::string> _slrgFomMode;
     std::map<u_int32_t, std::string> _pcieDevStatus;
+    std::map<u_int32_t, PcieErrType> _pcieErrType;
 
     string _sltpHeader;
-    string _berCollectTitle;
     string _showErrorsTitle;
 };
 
