@@ -36,17 +36,23 @@
 
 MlxlinkRegParser::MlxlinkRegParser() : RegAccessParser("", "", "", NULL, 0)
 {
-    _mf = NULL;
-    _regLib = NULL;
+    _mf = nullptr;
+    _regLib = nullptr;
     _gvmiAddress = 0;
-    _mlxlinkLogger = NULL;
+
+    _localPort = 0;
+    _portType = 0;
+    _pnat = 0;
+    _planeInd = -1;
+
+    _isHCA = false;
+    _isSwControled = false;
 }
 
 MlxlinkRegParser::~MlxlinkRegParser() {}
 
 void MlxlinkRegParser::resetParser(const string& regName)
 {
-    DEBUG_LOG(_mlxlinkLogger, "%s: %-30s\n", "OPERATION ON REGISTER", (char*)regName.c_str());
     _regNode = (_regLib)->findAdbNode(regName);
     _data = "";
     _indexes = "";
@@ -74,7 +80,6 @@ void MlxlinkRegParser::resetParser(const string& regName)
 
 void MlxlinkRegParser::genBuffSendRegister(const string& regName, maccess_reg_method_t method)
 {
-    DEBUG_LOG(_mlxlinkLogger, "%-15s: %s\n", "ACCESS_METHOD", method == MACCESS_REG_METHOD_GET ? "GET" : "SET");
     if (_gvmiAddress)
     {
         writeGvmi(1);
@@ -95,9 +100,6 @@ void MlxlinkRegParser::writeGvmi(u_int32_t data)
 
 void MlxlinkRegParser::updateField(string field_name, u_int32_t value)
 {
-    DEBUG_LOG(_mlxlinkLogger, "%-15s: %-30s\tVALUE: 0x%08x (%d)\n", "UPDATE_FIELD", (char*)field_name.c_str(), value,
-              value);
-
     RegAccessParser::updateField(field_name, value);
 
     if (field_name == "local_port")
@@ -115,6 +117,74 @@ void MlxlinkRegParser::updateField(string field_name, u_int32_t value)
     }
 }
 
+void MlxlinkRegParser::updateWithDefault(const string& fieldName, const string& fieldsStr, u_int32_t val)
+{
+    if (fieldsStr.find(fieldName) == string::npos)
+    {
+        try
+        {
+            updateField(fieldName, val);
+        }
+        catch (...)
+        {
+        }
+    }
+}
+
+void MlxlinkRegParser::setDefaultFields(const string& regName, const string& fieldsStr)
+{
+    updateWithDefault("local_port", fieldsStr, _localPort);
+    updateWithDefault("pnat", fieldsStr, _pnat);
+
+    if (!_isHCA)
+    {
+        updateWithDefault("port_type", fieldsStr, _portType);
+    }
+
+    // Some registers need to have another indication for localport 255 to deal with it as a localport by setting lp_gl
+    // field
+    if (regName == ACCESS_REG_PPCNT && _localPort == 255)
+    {
+        updateWithDefault("lp_gl", fieldsStr, 1);
+    }
+}
+
+void MlxlinkRegParser::sendPrmReg(const string& regName, maccess_reg_method_t method)
+{
+    resetParser(regName);
+
+    setDefaultFields(regName, "");
+
+    genBuffSendRegister(regName, method);
+}
+
+void MlxlinkRegParser::sendPrmReg(const string& regName, maccess_reg_method_t method, const char* fields, ...)
+{
+    char fieldsCstr[MAX_FIELDS_BUFFER];
+    va_list args;
+    va_start(args, fields);
+    vsnprintf(fieldsCstr, MAX_FIELDS_BUFFER, fields, args);
+    va_end(args);
+
+    string fieldsStr = string(fieldsCstr);
+    auto vectorOffields = MlxlinkRecord::split(fieldsStr, ",");
+
+    resetParser(regName);
+
+    for (const auto& token : vectorOffields)
+    {
+        auto fieldToken = MlxlinkRecord::split(token, "=");
+        string fieldName = fieldToken[0];
+        u_int32_t fieldValue = stoi(fieldToken[1], nullptr, 0);
+
+        updateField(fieldName, fieldValue);
+    }
+
+    setDefaultFields(regName, fieldsStr);
+
+    genBuffSendRegister(regName, method);
+}
+
 string MlxlinkRegParser::getFieldStr(const string& field)
 {
     return to_string(getFieldValue(field));
@@ -152,10 +222,7 @@ string MlxlinkRegParser::getRawFieldValueStr(const string fieldName)
 
 u_int32_t MlxlinkRegParser::getFieldValue(string field_name)
 {
-    u_int32_t field_Val = RegAccessParser::getFieldValue(field_name, _buffer);
-    DEBUG_LOG(_mlxlinkLogger, "%-15s: %-30s\tVALUE: 0x%08x (%d)\n", "GET_FIELD", (char*)field_name.c_str(), field_Val,
-              field_Val);
-    return field_Val;
+    return RegAccessParser::getFieldValue(field_name, _buffer);
 }
 
 u_int32_t MlxlinkRegParser::getFieldSize(string field_name)
