@@ -1,6 +1,6 @@
 /*
  * Copyright (C) Jan 2013 Mellanox Technologies Ltd. All rights reserved.
- * Copyright (c) 2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
+ * Copyright (c) 2021-2024 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -47,9 +47,11 @@
 #include <sched.h>
 
 #include "mtcr.h"
-#include <compatibility.h>
-#include <bit_slice.h>
+#include "common/compatibility.h"
+#include "common/bit_slice.h"
+#include "common/tools_time.h"
 #include <stdlib.h>
+#include "tools_dev_types.h"
 
 #include <unistd.h>
 
@@ -114,7 +116,7 @@ static int _flock_int(int fdlock, int operation)
         {
             break; // BAD! lock/free failed
         }
-        usleep(10);
+        mft_usleep(10);
         cnt++;
     } while (cnt < FREEBSD_MAX_RETRY_CNT);
     perror("failed to perform lock operation.");
@@ -1297,7 +1299,8 @@ int mwrite_i2cblock(mfile* mf, unsigned char i2c_slave, u_int8_t addr_width, uns
     return 0;
 }
 
-static void fix_endianness(u_int32_t* buf, int len)
+// TODO: Introduce a module to keep platform-independent routines like this one below
+void mtcr_fix_endianness(u_int32_t* buf, int len)
 {
     int i;
 
@@ -1313,13 +1316,13 @@ int mread_buffer(mfile* mf, unsigned int offset, u_int8_t* data, int byte_len)
 {
     int rc;
     rc = mread4_block(mf, offset, (u_int32_t*)data, byte_len);
-    fix_endianness((u_int32_t*)data, byte_len);
+    mtcr_fix_endianness((u_int32_t*)data, byte_len);
     return rc;
 }
 
 int mwrite_buffer(mfile* mf, unsigned int offset, u_int8_t* data, int byte_len)
 {
-    fix_endianness((u_int32_t*)data, byte_len);
+    mtcr_fix_endianness((u_int32_t*)data, byte_len);
     return mwrite4_block(mf, offset, (u_int32_t*)data, byte_len);
 }
 
@@ -3015,4 +3018,49 @@ int mlxcables_remote_operation_client_side(mfile* mf, const char* device_name, c
     (void)flags;
     (void)reg_name;
     return 0;
-}
\ No newline at end of file
+}
+
+int is_remote_dev(mfile* mf)
+{
+    if (mf)
+    {
+        return mf->is_remote;
+    }
+
+    return 0;
+}
+
+
+int is_zombiefish_device(mfile* mf)
+{
+    size_t gis_address = 0; // gis == global image status
+    u_int32_t gis = 0;
+    uint32_t gis_operational = 0; // for NICs and HCAs
+
+    u_int32_t hw_dev_id = 0;
+    if (mread4_old(mf, HW_ID_ADDR, &hw_dev_id) != 4) {
+        return 0;
+    }
+
+    switch (hw_dev_id & 0xffff)
+    {
+        case DeviceConnectX8_HwId:
+            gis_address = 0xE3044;
+            break;
+        case DeviceQuantum3_HwId:
+            gis_operational = 0x5E;
+            gis_address = 0x152080;
+            break;
+        default:
+            return 0; // Device does not support Zombiefish mode
+    }
+
+    int rc = mread4_old(mf, gis_address, &gis);
+    if (rc != 4)
+    {
+        // printf("-E- Failed to read global_image_status from CR space.\n");
+        return 0;
+    }
+
+    return (gis != gis_operational);
+}
