@@ -63,7 +63,8 @@ extern "C"
 
     int msw_reset_ul(mfile* mf);
     int mhca_reset_ul(mfile* mf);
-
+    int is_remote_dev(mfile* mf);
+    
     /*
      * Get list of MST_ul(Mellanox Software Tools) devices.
      * Put all device names as null-terminated strings to buf.
@@ -166,6 +167,10 @@ extern "C"
 
     int read_dword_from_conf_space(mfile* mf, u_int32_t offset, u_int32_t* data);
 
+    void mtcr_fix_endianness(u_int32_t* buf, int len);
+
+    int is_zombiefish_device(mfile* mf);
+
 #ifdef __cplusplus
 }
 #endif
