@@ -109,6 +109,7 @@
 
 #define REG_ID_MDDT 0x9160
 #define REG_ID_MDDQ 0x9161
+#define REG_ID_PGUID 0x5066
 
 // For mstdump oob feature:
 #define REG_ID_ICAM 0x387F
@@ -117,6 +118,7 @@
 //==================================
 // RESOURCE DUMP FEATURE
 #define REG_ID_RES_DUMP 0xC000
+#define REG_ID_MORD 0x9153
 //==================================
 #define REG_ID_MPEGC 0x9056
 #define REG_ID_NIC_CAP_EXT 0xC011
@@ -356,6 +358,12 @@ reg_access_status_t reg_access_mmdio(mfile* mf, reg_access_method_t method, stru
 /************************************
  * * Function: reg_access_resource_dump
  * ************************************/
+
+/***********************************************************/
+/*********************** ATTENTION *************************/
+/** The registers below must be same (except for the ID) ***/
+/** Changes in them should be made both in switch and nic **/
+
 reg_access_status_t
   reg_access_res_dump(mfile* mf, reg_access_method_t method, struct reg_access_hca_resource_dump_ext* resource_dump)
 {
@@ -366,6 +374,12 @@ reg_access_status_t
     }
     REG_ACCCESS(mf, method, REG_ID_RES_DUMP, resource_dump, resource_dump_ext, reg_access_hca);
 }
+
+reg_access_status_t
+  reg_access_mord(mfile* mf, reg_access_method_t method, struct reg_access_hca_resource_dump_ext* resource_dump)
+{
+    REG_ACCCESS(mf, method, REG_ID_MORD, resource_dump, resource_dump_ext, reg_access_hca);
+}
 //=================================================================================================================================
 
 reg_access_status_t reg_access_mnvda(mfile* mf, reg_access_method_t method, struct tools_open_mnvda* mnvda)
@@ -797,4 +811,12 @@ reg_access_status_t reg_access_dtor(mfile* mf, reg_access_method_t method, struc
 reg_access_status_t reg_access_mrsi(mfile* mf, reg_access_method_t method, struct reg_access_hca_mrsi_ext* mrsi)
 {
     REG_ACCCESS(mf, method, REG_ID_MRSI, mrsi, mrsi_ext, reg_access_hca);
+}
+
+/************************************
+ * Function: reg_access_pguid
+ ************************************/
+reg_access_status_t reg_access_pguid(mfile* mf, reg_access_method_t method, struct reg_access_hca_pguid_reg_ext* pguid)
+{
+    REG_ACCCESS(mf, method, REG_ID_PGUID, pguid, pguid_reg_ext, reg_access_hca);
 }
\ No newline at end of file
