@@ -123,8 +123,7 @@ MLNX_DEVICES = [
 # Supported devices.
 SUPP_DEVICES = ["ConnectIB", "ConnectX4", "ConnectX4LX", "ConnectX5", "BlueField",
                 "ConnectX6", "ConnectX6DX", "ConnectX6LX", "BlueField2", "ConnectX7", "BlueField3", "ConnectX8", "BlueField4"]
-SUPP_SWITCH_DEVICES = ["Spectrum", "Spectrum-2", "Spectrum-3", "Spectrum-4",
-                       "Switch-IB", "Switch-IB-2", "Quantum", "Quantum-2", "Quantum-3"]
+SUPP_SWITCH_DEVICES = ["Spectrum", "Spectrum-2", "Spectrum-3", "Switch-IB", "Switch-IB-2", "Quantum", "Quantum-2"]
 SUPP_OS = ["FreeBSD", "Linux", "Windows"]
 
 IS_MSTFLINT = os.path.basename(__file__) == "mstfwreset.py"
@@ -176,7 +175,7 @@ FWResetStatusChecker = None
 # Global options
 SkipMstRestart = False
 SkipMultihostSync = False
-is_cedar = False
+is_pcie_switch = False
 is_bluefield = False
 logger = None
 device_global = None
@@ -187,11 +186,17 @@ pathToPciModuleDir = "/etc/mft/mlxfwreset"
 SUPPORTED_DEVICES_WITH_SWITCHES = [
     "15b3", "10ee", "1af4"]  # 1af4 for Red Hat (virtio)
 
+PSID_CEDAR_VALUES = ["MT_0000000891", "MT_0000000929", "MT_0000000937"]
+PSID_PROMETHEUS_VALUS = ["NVD0000000033"]
+PSID_ZT_VALUS = ["MSF0000000047"]
+ALL_PSID_PCIE_SWITCH = PSID_CEDAR_VALUES + PSID_PROMETHEUS_VALUS + PSID_ZT_VALUS
 
 ######################################################################
 # Description:  Pcnr Exception
 # OS Support :  Linux.
 ######################################################################
+
+
 class PcnrError(Exception):
     pass
 
@@ -805,13 +810,27 @@ class MlnxPciOpFactory(object):
         else:
             raise RuntimeError("Unsupported OS: %s" % operatingSystem)
 
+
+def CloseAndMstRestart(lspci_valdation=True):
+    # We close MstDevObj to allow a clean operation of mst restart
+    MstDevObj.close()
+    for MstDevObjSD in MstDevObjsSD:
+        MstDevObjSD.close()
+
+    if SkipMstRestart == False and platform.system() == "Linux" and not IS_MSTFLINT:
+        printAndFlush("-I- %-40s-" % ("Restarting MST"), endChar="")
+        if mstRestart(lspci_valdation) == 0:
+            printAndFlush("Done")
+        else:
+            printAndFlush("Skipped")
+
 ######################################################################
 # Description:  Perform mst restart
 # OS Support :  Linux.
 ######################################################################
 
 
-def mstRestart(busId):
+def mstRestart(lspci_valdation):
     global MstFlags
     if platform.system() == "FreeBSD" or platform.system() == "Windows":
         return 1
@@ -833,22 +852,23 @@ def mstRestart(busId):
         else:
             time.sleep(2)
 
-    cmd = "lspci -s %s" % busId
-    logger.debug('Execute {0}'.format(cmd))
-    foundBus = False
-    rc = 0
-    for _ in range(0, 30):
-        (rc, stdout, _) = cmdExec(cmd)
-        if rc == 0 and stdout != "":
-            foundBus = True
-            break
-        else:
-            time.sleep(2)
-    if rc != 0:
-        raise WarningException(
-            "Failed to run lspci command, please restart MST manually")
-    if not foundBus:
-        raise RuntimeError("The device is not appearing in lspci output!")
+    if lspci_valdation is True:
+        cmd = "lspci -s %s" % DevDBDF
+        logger.debug('Execute {0}'.format(cmd))
+        foundBus = False
+        rc = 0
+        for _ in range(0, 30):
+            (rc, stdout, _) = cmdExec(cmd)
+            if rc == 0 and stdout != "":
+                foundBus = True
+                break
+            else:
+                time.sleep(2)
+        if rc != 0:
+            raise WarningException(
+                "Failed to run lspci command, please restart MST manually")
+        if not foundBus:
+            raise RuntimeError("The device is not appearing in lspci output!")
 
     ignore_signals()
     cmd = "/etc/init.d/mst restart %s" % MstFlags
@@ -1329,33 +1349,33 @@ def is_pci_bridge_is_mellanox_device(devAddr):
         return False
 
 
-def send_reset_cmd_to_cedar_devices(reset_level, reset_type, reset_sync):
+def send_reset_cmd_to_pcie_switch_devices(reset_level, reset_type, reset_sync):
     #
-    # We are going to send MFRL request for all the Cedar devices on the host.
+    # We are going to send MFRL request for all the PCIE switch devices on the host.
     #
 
-    # Discover all Cedar devices.
-    peripherals = MlnxPeripheralComponents()
+    # Discover all PCIE switch devices.
+    peripherals = MlnxPeripheralComponents(logger)
     for pci_device in peripherals.pci_devices:
         logger.debug("Creating regaccess obj for device %s" % pci_device.get_alias())
         pci_device_mst = mtcr.MstDevice(pci_device.get_alias())
         pci_device_reg_access = regaccess.RegAccess(pci_device_mst)
-        if is_cedar_device(pci_device.get_cfg_did(), pci_device_reg_access):
-            # Create MFRL for each Cedar device.
+        if is_pcie_switch_device(pci_device.get_cfg_did(), pci_device_reg_access):
+            # Create MFRL for each PCIE switch device.
             logger.debug("Creating MFRL for device %s" % pci_device.get_alias())
-            cedar_device_mfrl = CmdRegMfrl(pci_device_reg_access, logger)
+            mfrl = CmdRegMfrl(pci_device_reg_access, logger)
             # Send MFRL reset.
             printAndFlush("-I- %-40s-" %
                           ("Sending Reset Command To Fw"), endChar="")
             logger.debug('[Timing Test] MFRL')
-            cedar_device_mfrl.send(reset_level, reset_type, reset_sync, True)
+            mfrl.send(reset_level, reset_type, reset_sync)
             printAndFlush("Done")
 
 
 def send_reset_cmd_to_fw(mfrl, reset_level, reset_type, reset_sync=SyncOwner.TOOL):
     try:
-        if is_cedar:
-            send_reset_cmd_to_cedar_devices(reset_level, reset_type, reset_sync)
+        if is_pcie_switch:
+            send_reset_cmd_to_pcie_switch_devices(reset_level, reset_type, reset_sync)
             return
 
         printAndFlush("-I- %-40s-" %
@@ -1368,28 +1388,15 @@ def send_reset_cmd_to_fw(mfrl, reset_level, reset_type, reset_sync=SyncOwner.TOO
         raise e
 
 
-def is_cedar_device(devid, reg_access_obj=None):
+def is_pcie_switch_device(devid, reg_access_obj=None):
     res = False
     reg_access_obj = RegAccessObj if reg_access_obj is None else reg_access_obj
     devDict = getDeviceDict(devid)
     if devDict['name'] == 'ConnectX7':
         psid = reg_access_obj.getPSID()
         logger.debug("ConnectX7 device with PSID: %s" % psid)
-        if psid in ["MT_0000000891", "MT_0000000929", "MT_0000000937"]:
-            logger.debug("Found Cedar device")
-            res = True
-    return res
-
-
-def is_prometheus_device(devid, reg_access_obj=None):
-    res = False
-    reg_access_obj = RegAccessObj if reg_access_obj is None else reg_access_obj
-    devDict = getDeviceDict(devid)
-    if devDict['name'] == 'ConnectX7':
-        psid = reg_access_obj.getPSID()
-        logger.debug("ConnectX7 device with PSID: %s" % psid)
-        if psid in ["NVD0000000033"]:
-            logger.debug("Found Prometheus device")
+        if psid in ALL_PSID_PCIE_SWITCH:
+            logger.debug("Found PCIE switch device")
             res = True
     return res
 
@@ -1634,17 +1641,8 @@ def resetFlow(device, devicesSD, reset_level, reset_type, cmdLineArgs, mfrl):
         logger.debug('UpdateUptimeAfterReset')
         FWResetStatusChecker.UpdateUptimeAfterReset()
 
-        # we close MstDevObj to allow a clean operation of mst restart
-        MstDevObj.close()
-        for MstDevObjSD in MstDevObjsSD:  # Roei close mst devices for all "other" devices
-            MstDevObjSD.close()
+        CloseAndMstRestart()
 
-        if SkipMstRestart == False and platform.system() == "Linux" and not IS_MSTFLINT:
-            printAndFlush("-I- %-40s-" % ("Restarting MST"), endChar="")
-            if mstRestart(DevDBDF) == 0:
-                printAndFlush("Done")
-            else:
-                printAndFlush("Skipped")
     except Exception as e:
         reset_fsm_register()
         printAndFlush("Failed")
@@ -1700,11 +1698,12 @@ def check_if_pci_link_is_down(root_pci_device, mfrl, dtor_result):
 
     start_time = time.time()
     # Continuously monitoring the active register of the DLL link until the link goes down
+    timeout = timeout_in_milliseconds_until_the_pci_link_goes_down / 1000
+    error_msg = "The PCI link is still up even after the expected time ({0}) seconds has passed. Exiting the process.".format(timeout)
     while root_pci_device.dll_link_active == 1:
         if is_in_shutdown_progress is False:
             is_in_shutdown_progress = check_if_shut_down_in_progress(mfrl)
-
-        check_if_elapsed_time(start_time, "up", timeout_in_milliseconds_until_the_pci_link_goes_down / 1000)
+        check_if_elapsed_time(start_time, timeout, error_msg)
 
     logger.debug("Link is down")
 
@@ -1732,17 +1731,20 @@ def check_if_pci_link_is_up(root_pci_device, dtor_result):
     logger.debug('timeout_in_milliseconds_until_the_pci_link_goes_up = {0}'.format(timeout_in_milliseconds_until_the_pci_link_goes_up))
 
     # Continuously monitoring the active register of the DLL link until the link goes up
+    timeout = timeout_in_milliseconds_until_the_pci_link_goes_up / 1000
+    error_msg = "The PCI link is still down even after the expected time ({0}) seconds has passed. Exiting the process".format(timeout)
     while root_pci_device.dll_link_active == 0:
-        check_if_elapsed_time(start_time, "down", timeout_in_milliseconds_until_the_pci_link_goes_up / 1000)
+        check_if_elapsed_time(start_time, timeout, error_msg)
 
     logger.debug("Link is up")
 
 
-def check_if_elapsed_time(start_time, state, timeout):
+def check_if_elapsed_time(start_time, timeout, error_msg):
     current_time = time.time()
     elapsed_time = current_time - start_time
+    logger.debug('elapsed_time = {0}'.format(elapsed_time))
     if elapsed_time >= timeout:
-        raise RuntimeError("The PCI link is still {0} even after the expected time ({1}) seconds has passed. Exiting the process.".format(state, timeout))
+        raise RuntimeError(error_msg)
 
 
 def check_if_shut_down_in_progress(mfrl):
@@ -1753,6 +1755,8 @@ def check_if_shut_down_in_progress(mfrl):
     except BaseException:
         pass
     else:
+        mfrl.is_reset_state_in_error()
+
         if mfrl.is_reset_state_in_progress() is True:
             print("Arm OS shut down in progress, the completion of the process may take several minutes.")
             res = True
@@ -1784,6 +1788,11 @@ def execute_driver_sync_reset(mfrl, reset_level, reset_type):
         logger.debug('UpdateUptimeAfterReset')
         FWResetStatusChecker.UpdateUptimeAfterReset()
 
+        # When Hotplug is activated, resetting the device causes the bdf to change.
+        # As a result, running lspci on the previously known bdf will not be successful due to the altered bdf.
+        # Running mst restart is necessary to re-enumerate the mst devices.
+        CloseAndMstRestart(lspci_valdation=False)
+
 ######################################################################
 # Description:  execute sync 1 reset for BF
 ######################################################################
@@ -1819,19 +1828,51 @@ def execute_driver_sync_reset_bf(mfrl, reset_level, reset_type):
         elif mfrl_error:
             logger.debug("MFRL sync 1 worked although MFRL returned with error: {0}".format(mfrl_error))
 
+
+def send_mrsi(mrsi):
+    max_retries = 5
+    retry_count = 0
+    status = 0
+    while retry_count < max_retries:
+        try:
+            status = mrsi.get_ecos(CmdRegMrsi.EMBEDDED_CPU_DEVICE)
+        except Exception:
+            retry_count += 1
+        else:
+            break  # If the function call succeeds, break out of the loop
+    else:
+        raise RuntimeError("Maximum retries reached. Unable to retrieve ecos from mrsi register.")
+    return status
+
+######################################################################
+# Description: Resetting only the ARM side
+######################################################################
+
+
+def arm_reset(reset_level, reset_type, reset_sync, mrsi, mfrl):
+    if reset_type not in [CmdRegMfrl.ARM_ONLY, CmdRegMfrl.ARM_OS_SHUTDOWN]:
+        raise RuntimeError("Only the reset types ARM reset (3) and ARM shut down (4) are considered valid reset types with reset level IMMEDIATE RESET (1).")
+
+    logger.debug('Sending MFRL register to reset only the ARM side ')
+    send_reset_cmd_to_fw(mfrl, reset_level, reset_type, reset_sync)
+    if reset_type is CmdRegMfrl.ARM_ONLY:
+        print("Issuing reset to the embedded CPU completed successfully")
+    else:
+        dtor_result = RegAccessObj.getDTOR()
+        timeout = get_timeout_in_miliseconds(dtor_result, "EMBEDDED_CPU_OS_SHUTDOWN_TO") / 1000
+        logger.debug('EMBEDDED_CPU_OS_SHUTDOWN timeout = {0}'.format(timeout))
+        start_time = time.time()
+        while send_mrsi(mrsi) is not CmdRegMrsi.LOW_POWER_STANDBY:
+            error_msg = "The ARM side has not started running (the ecos field is in state {0})".format(mrsi.get_ecos(CmdRegMrsi.EMBEDDED_CPU_DEVICE))
+            logger.debug('ecos status {0}'.format(mrsi.get_ecos(CmdRegMrsi.EMBEDDED_CPU_DEVICE)))
+            check_if_elapsed_time(start_time, timeout, error_msg)
+
 ######################################################################
 # Description:  execute reset level for device
 ######################################################################
 
 
-def execResLvl(device, devicesSD, reset_level, reset_type, reset_sync, cmdLineArgs, mfrl):
-
-    # mpcir usage removed due to RM #2214400
-    # # In new FW, the FW doesn't need this command any more
-    # if mfrl.is_phy_less_reset(reset_type):
-    #     logger.debug('[Timing Test] MPCIR')
-    #     mpcir.prepare_for_phyless_fw_upgrade()
-
+def execResLvl(device, devicesSD, reset_level, reset_type, reset_sync, cmdLineArgs, mfrl, mrsi):
     if reset_level == mfrl.LIVE_PATCH:
         send_reset_cmd_to_fw(mfrl, reset_level, reset_type)
     elif reset_level in [mfrl.PCI_RESET, mfrl.WARM_REBOOT]:
@@ -1843,6 +1884,9 @@ def execResLvl(device, devicesSD, reset_level, reset_type, reset_sync, cmdLineAr
         else:
             resetFlow(device, devicesSD, reset_level,
                       reset_type, cmdLineArgs, mfrl)
+
+    elif reset_level is mfrl.IMMEDIATE_RESET:
+        arm_reset(reset_level, reset_type, reset_sync, mrsi, mfrl)
     else:
         raise RuntimeError("Unknown reset level")
 
@@ -1955,9 +1999,6 @@ def reset_flow_host(device, args, command):
     mcam = CmdRegMcam(RegAccessObj)
     mrsi = CmdRegMrsi(RegAccessObj)
 
-    if is_prometheus_device(devid):
-        raise RuntimeError("Prometheus device is not supported")
-
     logger.info('Check if device is livefish')
     DevMgtObj = dev_mgt.DevMgt(MstDevObj)  # check if device is in livefish
     if DevMgtObj.isLivefishMode() == 1:
@@ -1981,7 +2022,7 @@ def reset_flow_host(device, args, command):
     if command == "reset" and not args.skip_socket_direct:
 
         try:
-            peripherals = MlnxPeripheralComponents()
+            peripherals = MlnxPeripheralComponents(logger)
             usr_pci_device = peripherals.get_pci_device(device)
             socket_direct_pci_devices = peripherals.get_socket_direct_pci_devices(
                 usr_pci_device)
@@ -1992,8 +2033,8 @@ def reset_flow_host(device, args, command):
                 MstDevObjsSD.append(mtcr.MstDevice(deviceSD))
                 RegAccessObjsSD.append(regaccess.RegAccess(MstDevObjsSD[-1]))
                 CmdifObjsSD.append(cmdif.CmdIf(MstDevObjsSD[-1]))
-        except BaseException:
-            logger.warning("Failed to check if device is Socket Direct!")
+        except BaseException as e:
+            logger.warning("Failed to check if device is Socket Direct!, ERROR [%s]" % e)
             devicesSD = []
             for MstDevObjSD in MstDevObjsSD:
                 MstDevObjSD.close()
@@ -2022,7 +2063,7 @@ def reset_flow_host(device, args, command):
         global is_bluefield
         is_bluefield = True
     if command == "query":
-        print(mfrl.query_text(is_cedar_device(devid)))
+        print(mfrl.query_text(is_pcie_switch_device(devid)))
         tool_owner_support = True
         if platform.system() == "Linux" and is_bluefield:
             tool_owner_support = False
@@ -2031,18 +2072,17 @@ def reset_flow_host(device, args, command):
             print(mrsi.query_text(is_bluefield))
 
     elif command == "reset":
-        if is_cedar_device(devid):
+        if is_pcie_switch_device(devid):
             if args.reset_level is None:
                 args.reset_level = CmdRegMfrl.WARM_REBOOT
             if args.reset_level is not CmdRegMfrl.WARM_REBOOT:
-                raise RuntimeError("Only reboot is supported for Cedar device")
-            else:
-                global is_cedar
-                is_cedar = True
+                raise RuntimeError("Only reboot is supported for PCIE switch device")
+            global is_pcie_switch
+            is_pcie_switch = True
 
         reset_level = mfrl.default_reset_level(
         ) if args.reset_level is None else args.reset_level
-        # print("  * reset-level is '{0}' ({1})".format(reset_level, mfrl.reset_level_description(reset_level)))
+
         if mfrl.is_reset_level_supported(reset_level) is False:
             raise RuntimeError(
                 "Reset-level '{0}' is not supported in the current state of this device".format(reset_level))
@@ -2057,28 +2097,32 @@ def reset_flow_host(device, args, command):
             raise RuntimeError(
                 "Reset-level '{0}' is not supported with reset-type '{1}'".format(reset_level, reset_type))
 
-        if reset_sync == SyncOwner.DRIVER and mcam.is_reset_by_fw_driver_sync_supported() is False:
+        if reset_level != CmdRegMfrl.IMMEDIATE_RESET and reset_sync == SyncOwner.DRIVER and mcam.is_reset_by_fw_driver_sync_supported() is False:
             raise RuntimeError(
                 "Synchronization by driver is not supported in the current state of this device")
-        if reset_sync != SyncOwner.TOOL and reset_level != CmdRegMfrl.PCI_RESET:
+        if reset_sync != SyncOwner.TOOL and reset_level not in [CmdRegMfrl.PCI_RESET, CmdRegMfrl.IMMEDIATE_RESET]:
             raise RuntimeError(
                 "Reset-sync '{0}' is not supported with reset-level '{1}'".format(reset_sync, reset_level))
 
-        minimal_or_requested = 'Minimal' if args.reset_level is None else 'Requested'
-        print("{0} reset level for device, {1}:\n".format(
-            minimal_or_requested, device))
+        print("The reset level for device, {0} is:\n".format(device))
         print("{0}: {1}".format(reset_level,
               mfrl.reset_level_description(reset_level)))
 
+        if reset_type in [CmdRegMfrl.ARM_ONLY, CmdRegMfrl.ARM_OS_SHUTDOWN] and reset_level != mfrl.IMMEDIATE_RESET:
+            raise RuntimeError("Reset type 3 and 4 are only valid when reset level is 1")
+
         if CmdRegMfrl.is_reset_level_trigger_is_pci_link(reset_level) and mcam.is_pci_rescan_required_supported() and mfrl.is_pci_rescan_required():
             print("-W- PCI rescan is required after device reset.")
 
         if is_bluefield:
-            print("Please be aware that resetting the Bluefield may take several minutes. Exiting the process in the middle of the waiting period will not halt the reset")
+            print("Please be aware that resetting the Bluefield may take several minutes. Exiting the process in the middle of the waiting period will not halt the reset.")
+            if reset_type not in [CmdRegMfrl.PHY_LESS, CmdRegMfrl.NIC_ONLY]:
+                print("The ARM side will be restarted, and it will be unavailable for a while.")
 
         AskUser("Continue with reset", args.yes)
+
         execResLvl(device, devicesSD, reset_level,
-                   reset_type, reset_sync, args, mfrl)
+                   reset_type, reset_sync, args, mfrl, mrsi)
         if FWResetStatusChecker.GetStatus() == FirmwareResetStatusChecker.FirmwareResetStatusFailed:
             reset_fsm_register()
             print("-E- Firmware reset failed, retry operation or reboot machine.")
@@ -2103,6 +2147,12 @@ def reset_flow_switch(device, args, command):
     MstDevObj = mtcr.MstDevice(device)
     RegAccessObj = regaccess.RegAccess(MstDevObj)
 
+    if MstDevObj.is_remote_device():
+        raise RuntimeError("Resetting the switch is not possible using remote access")
+
+    if isModuleLoaded("sx_core"):
+        raise RuntimeError("Resetting the switch is not possible because the SX_CORE driver is currently loaded")
+
     if not is_fw_ready(device):
         raise RuntimeError("FW is not ready to handle ICMD")
 
